/* Plugin.c generated by valac 0.56.19, the Vala compiler
 * generated from Plugin.vala, do not modify */

/* Copyright (c) 2015-2018 elementary LLC <https://elementary.io>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, Inc.,; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "pantheon-files-core.h"
#include <gtk/gtk.h>
#include <glib.h>
#include <glib-object.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _FilesPluginsParamSpecBase FilesPluginsParamSpecBase;

struct _FilesPluginsParamSpecBase {
	GParamSpec parent_instance;
};

static gpointer files_plugins_base_parent_class = NULL;

static void files_plugins_base_real_directory_loaded (FilesPluginsBase* self,
                                               GtkApplicationWindow* window,
                                               FilesAbstractSlot* view,
                                               FilesFile* directory);
static void files_plugins_base_real_context_menu (FilesPluginsBase* self,
                                           GtkWidget* widget,
                                           GList* files);
static void files_plugins_base_real_sidebar_loaded (FilesPluginsBase* self,
                                             GtkWidget* widget);
static void files_plugins_base_real_update_sidebar (FilesPluginsBase* self,
                                             GtkWidget* widget);
static void files_plugins_base_real_update_file_info (FilesPluginsBase* self,
                                               FilesFile* file);
static void files_plugins_base_finalize (FilesPluginsBase * obj);
static GType files_plugins_base_get_type_once (void);

static void
files_plugins_base_real_directory_loaded (FilesPluginsBase* self,
                                          GtkApplicationWindow* window,
                                          FilesAbstractSlot* view,
                                          FilesFile* directory)
{
	g_return_if_fail (window != NULL);
	g_return_if_fail (view != NULL);
	g_return_if_fail (directory != NULL);
}

void
files_plugins_base_directory_loaded (FilesPluginsBase* self,
                                     GtkApplicationWindow* window,
                                     FilesAbstractSlot* view,
                                     FilesFile* directory)
{
	FilesPluginsBaseClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_PLUGINS_BASE_GET_CLASS (self);
	if (_klass_->directory_loaded) {
		_klass_->directory_loaded (self, window, view, directory);
	}
}

static void
files_plugins_base_real_context_menu (FilesPluginsBase* self,
                                      GtkWidget* widget,
                                      GList* files)
{
	g_return_if_fail (widget != NULL);
}

void
files_plugins_base_context_menu (FilesPluginsBase* self,
                                 GtkWidget* widget,
                                 GList* files)
{
	FilesPluginsBaseClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_PLUGINS_BASE_GET_CLASS (self);
	if (_klass_->context_menu) {
		_klass_->context_menu (self, widget, files);
	}
}

static void
files_plugins_base_real_sidebar_loaded (FilesPluginsBase* self,
                                        GtkWidget* widget)
{
	g_return_if_fail (widget != NULL);
}

void
files_plugins_base_sidebar_loaded (FilesPluginsBase* self,
                                   GtkWidget* widget)
{
	FilesPluginsBaseClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_PLUGINS_BASE_GET_CLASS (self);
	if (_klass_->sidebar_loaded) {
		_klass_->sidebar_loaded (self, widget);
	}
}

static void
files_plugins_base_real_update_sidebar (FilesPluginsBase* self,
                                        GtkWidget* widget)
{
	g_return_if_fail (widget != NULL);
}

void
files_plugins_base_update_sidebar (FilesPluginsBase* self,
                                   GtkWidget* widget)
{
	FilesPluginsBaseClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_PLUGINS_BASE_GET_CLASS (self);
	if (_klass_->update_sidebar) {
		_klass_->update_sidebar (self, widget);
	}
}

static void
files_plugins_base_real_update_file_info (FilesPluginsBase* self,
                                          FilesFile* file)
{
	g_return_if_fail (file != NULL);
}

void
files_plugins_base_update_file_info (FilesPluginsBase* self,
                                     FilesFile* file)
{
	FilesPluginsBaseClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_PLUGINS_BASE_GET_CLASS (self);
	if (_klass_->update_file_info) {
		_klass_->update_file_info (self, file);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
files_plugins_base_interface_loaded (FilesPluginsBase* self,
                                     GtkWidget* widget)
{
	GtkWidget* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (widget != NULL);
	_tmp0_ = _g_object_ref0 (widget);
	_g_object_unref0 (self->window);
	self->window = _tmp0_;
}

FilesPluginsBase*
files_plugins_base_construct (GType object_type)
{
	FilesPluginsBase* self = NULL;
	self = (FilesPluginsBase*) g_type_create_instance (object_type);
	return self;
}

static void
files_plugins_value_base_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
files_plugins_value_base_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		files_plugins_base_unref (value->data[0].v_pointer);
	}
}

static void
files_plugins_value_base_copy_value (const GValue* src_value,
                                     GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = files_plugins_base_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
files_plugins_value_base_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
files_plugins_value_base_collect_value (GValue* value,
                                        guint n_collect_values,
                                        GTypeCValue* collect_values,
                                        guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		FilesPluginsBase * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = files_plugins_base_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
files_plugins_value_base_lcopy_value (const GValue* value,
                                      guint n_collect_values,
                                      GTypeCValue* collect_values,
                                      guint collect_flags)
{
	FilesPluginsBase ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = files_plugins_base_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
files_plugins_param_spec_base (const gchar* name,
                               const gchar* nick,
                               const gchar* blurb,
                               GType object_type,
                               GParamFlags flags)
{
	FilesPluginsParamSpecBase* spec;
	g_return_val_if_fail (g_type_is_a (object_type, FILES_PLUGINS_TYPE_BASE), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
files_plugins_value_get_base (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FILES_PLUGINS_TYPE_BASE), NULL);
	return value->data[0].v_pointer;
}

void
files_plugins_value_set_base (GValue* value,
                              gpointer v_object)
{
	FilesPluginsBase * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FILES_PLUGINS_TYPE_BASE));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, FILES_PLUGINS_TYPE_BASE));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		files_plugins_base_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		files_plugins_base_unref (old);
	}
}

void
files_plugins_value_take_base (GValue* value,
                               gpointer v_object)
{
	FilesPluginsBase * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FILES_PLUGINS_TYPE_BASE));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, FILES_PLUGINS_TYPE_BASE));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		files_plugins_base_unref (old);
	}
}

static void
files_plugins_base_class_init (FilesPluginsBaseClass * klass,
                               gpointer klass_data)
{
	files_plugins_base_parent_class = g_type_class_peek_parent (klass);
	((FilesPluginsBaseClass *) klass)->finalize = files_plugins_base_finalize;
	((FilesPluginsBaseClass *) klass)->directory_loaded = (void (*) (FilesPluginsBase*, GtkApplicationWindow*, FilesAbstractSlot*, FilesFile*)) files_plugins_base_real_directory_loaded;
	((FilesPluginsBaseClass *) klass)->context_menu = (void (*) (FilesPluginsBase*, GtkWidget*, GList*)) files_plugins_base_real_context_menu;
	((FilesPluginsBaseClass *) klass)->sidebar_loaded = (void (*) (FilesPluginsBase*, GtkWidget*)) files_plugins_base_real_sidebar_loaded;
	((FilesPluginsBaseClass *) klass)->update_sidebar = (void (*) (FilesPluginsBase*, GtkWidget*)) files_plugins_base_real_update_sidebar;
	((FilesPluginsBaseClass *) klass)->update_file_info = (void (*) (FilesPluginsBase*, FilesFile*)) files_plugins_base_real_update_file_info;
}

static void
files_plugins_base_instance_init (FilesPluginsBase * self,
                                  gpointer klass)
{
	self->ref_count = 1;
}

static void
files_plugins_base_finalize (FilesPluginsBase * obj)
{
	FilesPluginsBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FILES_PLUGINS_TYPE_BASE, FilesPluginsBase);
	g_signal_handlers_destroy (self);
	_g_object_unref0 (self->window);
}

 G_GNUC_NO_INLINE static GType
files_plugins_base_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { files_plugins_value_base_init, files_plugins_value_base_free_value, files_plugins_value_base_copy_value, files_plugins_value_base_peek_pointer, "p", files_plugins_value_base_collect_value, "p", files_plugins_value_base_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (FilesPluginsBaseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) files_plugins_base_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FilesPluginsBase), 0, (GInstanceInitFunc) files_plugins_base_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType files_plugins_base_type_id;
	files_plugins_base_type_id = g_type_register_fundamental (g_type_fundamental_next (), "FilesPluginsBase", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
	return files_plugins_base_type_id;
}

GType
files_plugins_base_get_type (void)
{
	static volatile gsize files_plugins_base_type_id__once = 0;
	if (g_once_init_enter (&files_plugins_base_type_id__once)) {
		GType files_plugins_base_type_id;
		files_plugins_base_type_id = files_plugins_base_get_type_once ();
		g_once_init_leave (&files_plugins_base_type_id__once, files_plugins_base_type_id);
	}
	return files_plugins_base_type_id__once;
}

gpointer
files_plugins_base_ref (gpointer instance)
{
	FilesPluginsBase * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
files_plugins_base_unref (gpointer instance)
{
	FilesPluginsBase * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		FILES_PLUGINS_BASE_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

