/* SearchableInterface.c generated by valac 0.56.19, the Vala compiler
 * generated from SearchableInterface.vala, do not modify */

#include "pantheon-files-core.h"
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	FILES_VIEW_CHROME_SEARCHABLE_FILE_SELECTED_SIGNAL,
	FILES_VIEW_CHROME_SEARCHABLE_FILE_ACTIVATED_SIGNAL,
	FILES_VIEW_CHROME_SEARCHABLE_CURSOR_CHANGED_SIGNAL,
	FILES_VIEW_CHROME_SEARCHABLE_FIRST_MATCH_FOUND_SIGNAL,
	FILES_VIEW_CHROME_SEARCHABLE_EXIT_SIGNAL,
	FILES_VIEW_CHROME_SEARCHABLE_NUM_SIGNALS
};
static guint files_view_chrome_searchable_signals[FILES_VIEW_CHROME_SEARCHABLE_NUM_SIGNALS] = {0};

static GType files_view_chrome_searchable_get_type_once (void);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

void
files_view_chrome_searchable_cancel (FilesViewChromeSearchable* self)
{
	FilesViewChromeSearchableIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = FILES_VIEW_CHROME_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->cancel) {
		_iface_->cancel (self);
	}
}

void
files_view_chrome_searchable_search (FilesViewChromeSearchable* self,
                                     const gchar* txt,
                                     GFile* search_location)
{
	FilesViewChromeSearchableIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = FILES_VIEW_CHROME_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->search) {
		_iface_->search (self, txt, search_location);
	}
}

static void
files_view_chrome_searchable_default_init (FilesViewChromeSearchableIface * iface,
                                           gpointer iface_data)
{
	files_view_chrome_searchable_signals[FILES_VIEW_CHROME_SEARCHABLE_FILE_SELECTED_SIGNAL] = g_signal_new ("file-selected", FILES_VIEW_CHROME_TYPE_SEARCHABLE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, g_file_get_type ());
	files_view_chrome_searchable_signals[FILES_VIEW_CHROME_SEARCHABLE_FILE_ACTIVATED_SIGNAL] = g_signal_new ("file-activated", FILES_VIEW_CHROME_TYPE_SEARCHABLE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, g_file_get_type ());
	files_view_chrome_searchable_signals[FILES_VIEW_CHROME_SEARCHABLE_CURSOR_CHANGED_SIGNAL] = g_signal_new ("cursor-changed", FILES_VIEW_CHROME_TYPE_SEARCHABLE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, g_file_get_type ());
	files_view_chrome_searchable_signals[FILES_VIEW_CHROME_SEARCHABLE_FIRST_MATCH_FOUND_SIGNAL] = g_signal_new ("first-match-found", FILES_VIEW_CHROME_TYPE_SEARCHABLE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, g_file_get_type ());
	files_view_chrome_searchable_signals[FILES_VIEW_CHROME_SEARCHABLE_EXIT_SIGNAL] = g_signal_new ("exit", FILES_VIEW_CHROME_TYPE_SEARCHABLE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
}

 G_GNUC_NO_INLINE static GType
files_view_chrome_searchable_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (FilesViewChromeSearchableIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) files_view_chrome_searchable_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType files_view_chrome_searchable_type_id;
	files_view_chrome_searchable_type_id = g_type_register_static (G_TYPE_INTERFACE, "FilesViewChromeSearchable", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (files_view_chrome_searchable_type_id, gtk_widget_get_type ());
	return files_view_chrome_searchable_type_id;
}

GType
files_view_chrome_searchable_get_type (void)
{
	static volatile gsize files_view_chrome_searchable_type_id__once = 0;
	if (g_once_init_enter (&files_view_chrome_searchable_type_id__once)) {
		GType files_view_chrome_searchable_type_id;
		files_view_chrome_searchable_type_id = files_view_chrome_searchable_get_type_once ();
		g_once_init_leave (&files_view_chrome_searchable_type_id__once, files_view_chrome_searchable_type_id);
	}
	return files_view_chrome_searchable_type_id__once;
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

