/* DetailsColumn.c generated by valac 0.56.19, the Vala compiler
 * generated from DetailsColumn.vala, do not modify */

/*
 * SPDX-License-Identifier: GPL-2.0-or-later
 * SPDX-FileCopyrightText: 2020-2025 elementary, Inc. (https://elementary.io)
 *
 * Authors : Andres Mendez <shiruken@gmail.com>
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include "pantheon-files-core.h"
#include <gio/gio.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <granite.h>
#include <poppler.h>
#include <cairo-gobject.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>

#define FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE 512
#define FILES_VIEW_DETAILS_COLUMN_PREVIEW_H_MARGIN 24
#define FILES_VIEW_DETAILS_COLUMN_MAX_PREVIEW_FILE_SIZE (((2 * 8) * 1024) * 1024)
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define FILES_VIEW_TYPE_DETAILS_COLUMN (files_view_details_column_get_type ())
#define FILES_VIEW_DETAILS_COLUMN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumn))
#define FILES_VIEW_DETAILS_COLUMN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumnClass))
#define FILES_VIEW_IS_DETAILS_COLUMN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FILES_VIEW_TYPE_DETAILS_COLUMN))
#define FILES_VIEW_IS_DETAILS_COLUMN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FILES_VIEW_TYPE_DETAILS_COLUMN))
#define FILES_VIEW_DETAILS_COLUMN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumnClass))

typedef struct _FilesViewDetailsColumn FilesViewDetailsColumn;
typedef struct _FilesViewDetailsColumnClass FilesViewDetailsColumnClass;
typedef struct _FilesViewDetailsColumnPrivate FilesViewDetailsColumnPrivate;

#define FILES_TYPE_ABSTRACT_DIRECTORY_VIEW (files_abstract_directory_view_get_type ())
#define FILES_ABSTRACT_DIRECTORY_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FILES_TYPE_ABSTRACT_DIRECTORY_VIEW, FilesAbstractDirectoryView))
#define FILES_ABSTRACT_DIRECTORY_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FILES_TYPE_ABSTRACT_DIRECTORY_VIEW, FilesAbstractDirectoryViewClass))
#define FILES_IS_ABSTRACT_DIRECTORY_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FILES_TYPE_ABSTRACT_DIRECTORY_VIEW))
#define FILES_IS_ABSTRACT_DIRECTORY_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FILES_TYPE_ABSTRACT_DIRECTORY_VIEW))
#define FILES_ABSTRACT_DIRECTORY_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FILES_TYPE_ABSTRACT_DIRECTORY_VIEW, FilesAbstractDirectoryViewClass))

typedef struct _FilesAbstractDirectoryView FilesAbstractDirectoryView;
typedef struct _FilesAbstractDirectoryViewClass FilesAbstractDirectoryViewClass;
enum  {
	FILES_VIEW_DETAILS_COLUMN_0_PROPERTY,
	FILES_VIEW_DETAILS_COLUMN_WIDTH_PROPERTY,
	FILES_VIEW_DETAILS_COLUMN_FILE_PROPERTY,
	FILES_VIEW_DETAILS_COLUMN_VIEW_PROPERTY,
	FILES_VIEW_DETAILS_COLUMN_NUM_PROPERTIES
};
static GParamSpec* files_view_details_column_properties[FILES_VIEW_DETAILS_COLUMN_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _FilesViewDetailsColumnGetResolutionData FilesViewDetailsColumnGetResolutionData;
#define _cairo_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_destroy (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))

#define FILES_VIEW_TYPE_ABSTRACT_PROPERTIES_DIALOG (files_view_abstract_properties_dialog_get_type ())
#define FILES_VIEW_ABSTRACT_PROPERTIES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FILES_VIEW_TYPE_ABSTRACT_PROPERTIES_DIALOG, FilesViewAbstractPropertiesDialog))
#define FILES_VIEW_ABSTRACT_PROPERTIES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FILES_VIEW_TYPE_ABSTRACT_PROPERTIES_DIALOG, FilesViewAbstractPropertiesDialogClass))
#define FILES_VIEW_IS_ABSTRACT_PROPERTIES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FILES_VIEW_TYPE_ABSTRACT_PROPERTIES_DIALOG))
#define FILES_VIEW_IS_ABSTRACT_PROPERTIES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FILES_VIEW_TYPE_ABSTRACT_PROPERTIES_DIALOG))
#define FILES_VIEW_ABSTRACT_PROPERTIES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FILES_VIEW_TYPE_ABSTRACT_PROPERTIES_DIALOG, FilesViewAbstractPropertiesDialogClass))

typedef struct _FilesViewAbstractPropertiesDialog FilesViewAbstractPropertiesDialog;
typedef struct _FilesViewAbstractPropertiesDialogClass FilesViewAbstractPropertiesDialogClass;

#define FILES_VIEW_TYPE_PROPERTIES_WINDOW (files_view_properties_window_get_type ())
#define FILES_VIEW_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FILES_VIEW_TYPE_PROPERTIES_WINDOW, FilesViewPropertiesWindow))
#define FILES_VIEW_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FILES_VIEW_TYPE_PROPERTIES_WINDOW, FilesViewPropertiesWindowClass))
#define FILES_VIEW_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FILES_VIEW_TYPE_PROPERTIES_WINDOW))
#define FILES_VIEW_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FILES_VIEW_TYPE_PROPERTIES_WINDOW))
#define FILES_VIEW_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FILES_VIEW_TYPE_PROPERTIES_WINDOW, FilesViewPropertiesWindowClass))

typedef struct _FilesViewPropertiesWindow FilesViewPropertiesWindow;
typedef struct _FilesViewPropertiesWindowClass FilesViewPropertiesWindowClass;

struct _FilesViewDetailsColumn {
	GtkBin parent_instance;
	FilesViewDetailsColumnPrivate * priv;
};

struct _FilesViewDetailsColumnClass {
	GtkBinClass parent_class;
};

struct _FilesViewDetailsColumnPrivate {
	FilesFile* _file;
	FilesAbstractDirectoryView* _view;
	GCancellable* cancellable;
	GtkLabel* resolution_value;
	gboolean previewing_text;
};

struct _FilesViewDetailsColumnGetResolutionData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	FilesViewDetailsColumn* self;
	FilesFile* goffile;
	GFileInputStream* stream;
	GFile* file;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	gchar* resolution;
	gchar* _tmp3_;
	GFileInputStream* _tmp4_;
	GFile* _tmp5_;
	GCancellable* _tmp6_;
	GFileInputStream* _tmp7_;
	GFileInputStream* _tmp8_;
	GFileInputStream* _tmp9_;
	GdkPixbuf* pixbuf;
	GFileInputStream* _tmp10_;
	GCancellable* _tmp11_;
	GdkPixbuf* _tmp12_;
	GdkPixbuf* _tmp13_;
	GdkPixbuf* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	GError* e;
	GError* _tmp24_;
	const gchar* _tmp25_;
	GFileInputStream* _tmp26_;
	GError* _vala1_e;
	GError* _tmp27_;
	const gchar* _tmp28_;
	GtkLabel* _tmp29_;
	const gchar* _tmp30_;
	GError* _inner_error0_;
};

static gint FilesViewDetailsColumn_private_offset;
static gpointer files_view_details_column_parent_class = NULL;

VALA_EXTERN GType files_view_details_column_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FilesViewDetailsColumn, g_object_unref)
VALA_EXTERN GType files_abstract_directory_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FilesAbstractDirectoryView, g_object_unref)
VALA_EXTERN FilesViewDetailsColumn* files_view_details_column_new (FilesFile* file,
                                                       FilesAbstractDirectoryView* view);
VALA_EXTERN FilesViewDetailsColumn* files_view_details_column_construct (GType object_type,
                                                             FilesFile* file,
                                                             FilesAbstractDirectoryView* view);
VALA_EXTERN gchar* files_view_details_column_original_location (FilesFile* file);
VALA_EXTERN gchar* files_view_details_column_get_common_trash_orig (FilesFile* file);
VALA_EXTERN GFile* files_view_details_column_get_parent_loc (const gchar* path);
VALA_EXTERN gchar* files_view_details_column_filetype (FilesFile* file);
static void files_view_details_column_get_resolution_data_free (gpointer _data);
static void files_view_details_column_get_resolution (FilesViewDetailsColumn* self,
                                               FilesFile* goffile,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
static void files_view_details_column_get_resolution_finish (FilesViewDetailsColumn* self,
                                                      GAsyncResult* _res_);
static gboolean files_view_details_column_get_resolution_co (FilesViewDetailsColumnGetResolutionData* _data_);
static void files_view_details_column_get_resolution_ready (GObject* source_object,
                                                     GAsyncResult* _res_,
                                                     gpointer _user_data_);
static gchar* files_view_details_column_resolution (FilesViewDetailsColumn* self,
                                             FilesFile* file);
VALA_EXTERN gint files_view_details_column_get_width (FilesViewDetailsColumn* self);
VALA_EXTERN FilesFile* files_view_details_column_get_file (FilesViewDetailsColumn* self);
static void files_view_details_column_set_file (FilesViewDetailsColumn* self,
                                         FilesFile* value);
VALA_EXTERN FilesAbstractDirectoryView* files_view_details_column_get_view (FilesViewDetailsColumn* self);
static void files_view_details_column_set_view (FilesViewDetailsColumn* self,
                                         FilesAbstractDirectoryView* value);
static GObject * files_view_details_column_constructor (GType type,
                                                 guint n_construct_properties,
                                                 GObjectConstructParam * construct_properties);
VALA_EXTERN guint64 files_view_properties_window_file_real_size (FilesFile* gof);
VALA_EXTERN GtkLabel* files_make_key_label (const gchar* label);
VALA_EXTERN GtkLabel* files_make_value_label (const gchar* label);
static void _files_view_details_column___lambda41_ (FilesViewDetailsColumn* self);
VALA_EXTERN GtkWindow* files_get_active_window (void);
VALA_EXTERN FilesViewPropertiesWindow* files_view_properties_window_new (GList* _files,
                                                             FilesAbstractDirectoryView* _view,
                                                             GtkWindow* parent);
VALA_EXTERN FilesViewPropertiesWindow* files_view_properties_window_construct (GType object_type,
                                                                   GList* _files,
                                                                   FilesAbstractDirectoryView* _view,
                                                                   GtkWindow* parent);
VALA_EXTERN GType files_view_abstract_properties_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FilesViewAbstractPropertiesDialog, g_object_unref)
VALA_EXTERN GType files_view_properties_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FilesViewPropertiesWindow, g_object_unref)
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
static void __files_view_details_column___lambda41__gtk_button_clicked (GtkButton* _sender,
                                                                 gpointer self);
static void files_view_details_column_finalize (GObject * obj);
static GType files_view_details_column_get_type_once (void);
static void _vala_files_view_details_column_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_files_view_details_column_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);

static inline gpointer
files_view_details_column_get_instance_private (FilesViewDetailsColumn* self)
{
	return G_STRUCT_MEMBER_P (self, FilesViewDetailsColumn_private_offset);
}

FilesViewDetailsColumn*
files_view_details_column_construct (GType object_type,
                                     FilesFile* file,
                                     FilesAbstractDirectoryView* view)
{
	FilesViewDetailsColumn * self = NULL;
	g_return_val_if_fail (file != NULL, NULL);
	g_return_val_if_fail (view != NULL, NULL);
	self = (FilesViewDetailsColumn*) g_object_new (object_type, "file", file, "view", view, NULL);
	return self;
}

FilesViewDetailsColumn*
files_view_details_column_new (FilesFile* file,
                               FilesAbstractDirectoryView* view)
{
	return files_view_details_column_construct (FILES_VIEW_TYPE_DETAILS_COLUMN, file, view);
}

/** Also an adjusted copy from PropertiesWindow **/
gchar*
files_view_details_column_original_location (FilesFile* file)
{
	GFileInfo* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp21_;
	gchar* result;
	g_return_val_if_fail (file != NULL, NULL);
	_tmp0_ = file->info;
	_tmp1_ = g_file_info_get_attribute_byte_string (_tmp0_, G_FILE_ATTRIBUTE_TRASH_ORIG_PATH);
	if (_tmp1_ != NULL) {
		gchar* trash_orig_loc = NULL;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		_tmp2_ = files_view_details_column_get_common_trash_orig (file);
		trash_orig_loc = _tmp2_;
		_tmp3_ = trash_orig_loc;
		if (_tmp3_ != NULL) {
			gchar* orig_pth = NULL;
			GFileInfo* _tmp4_;
			const gchar* _tmp5_;
			gchar* _tmp6_;
			const gchar* _tmp7_;
			GFile* _tmp8_;
			GFile* _tmp9_;
			gchar* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			const gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
			_tmp4_ = file->info;
			_tmp5_ = g_file_info_get_attribute_byte_string (_tmp4_, G_FILE_ATTRIBUTE_TRASH_ORIG_PATH);
			_tmp6_ = g_strdup (_tmp5_);
			orig_pth = _tmp6_;
			_tmp7_ = orig_pth;
			_tmp8_ = files_view_details_column_get_parent_loc (_tmp7_);
			_tmp9_ = _tmp8_;
			_tmp10_ = g_file_get_uri (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = g_strconcat ("<a href=\"", _tmp11_, NULL);
			_tmp13_ = _tmp12_;
			_tmp14_ = g_strconcat (_tmp13_, "\">", NULL);
			_tmp15_ = _tmp14_;
			_tmp16_ = trash_orig_loc;
			_tmp17_ = g_strconcat (_tmp15_, _tmp16_, NULL);
			_tmp18_ = _tmp17_;
			_tmp19_ = g_strconcat (_tmp18_, "</a>", NULL);
			_tmp20_ = _tmp19_;
			_g_free0 (_tmp18_);
			_g_free0 (_tmp15_);
			_g_free0 (_tmp13_);
			_g_free0 (_tmp11_);
			_g_object_unref0 (_tmp9_);
			result = _tmp20_;
			_g_free0 (orig_pth);
			_g_free0 (trash_orig_loc);
			return result;
		}
		_g_free0 (trash_orig_loc);
	}
	_tmp21_ = g_strdup (_ ("Unknown"));
	result = _tmp21_;
	return result;
}

gchar*
files_view_details_column_filetype (FilesFile* file)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* result;
	g_return_val_if_fail (file != NULL, NULL);
	_tmp0_ = files_file_get_content_type (file);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	result = _tmp2_;
	return result;
}

static void
files_view_details_column_get_resolution_data_free (gpointer _data)
{
	FilesViewDetailsColumnGetResolutionData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->goffile);
	_g_object_unref0 (_data_->self);
	g_slice_free (FilesViewDetailsColumnGetResolutionData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
files_view_details_column_get_resolution (FilesViewDetailsColumn* self,
                                          FilesFile* goffile,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_)
{
	FilesViewDetailsColumnGetResolutionData* _data_;
	FilesViewDetailsColumn* _tmp0_;
	FilesFile* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (goffile != NULL);
	_data_ = g_slice_new0 (FilesViewDetailsColumnGetResolutionData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, files_view_details_column_get_resolution_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (goffile);
	_g_object_unref0 (_data_->goffile);
	_data_->goffile = _tmp1_;
	files_view_details_column_get_resolution_co (_data_);
}

static void
files_view_details_column_get_resolution_finish (FilesViewDetailsColumn* self,
                                                 GAsyncResult* _res_)
{
	FilesViewDetailsColumnGetResolutionData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
files_view_details_column_get_resolution_ready (GObject* source_object,
                                                GAsyncResult* _res_,
                                                gpointer _user_data_)
{
	FilesViewDetailsColumnGetResolutionData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	files_view_details_column_get_resolution_co (_data_);
}

static gboolean
files_view_details_column_get_resolution_co (FilesViewDetailsColumnGetResolutionData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->stream = NULL;
	_data_->_tmp0_ = files_file_get_location (_data_->goffile);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = _g_object_ref0 (_data_->_tmp1_);
	_data_->file = _data_->_tmp2_;
	_data_->_tmp3_ = g_strdup (_ ("Could not be determined"));
	_data_->resolution = _data_->_tmp3_;
	{
		_data_->_tmp5_ = _data_->file;
		_data_->_tmp6_ = _data_->self->priv->cancellable;
		_data_->_state_ = 1;
		g_file_read_async (_data_->_tmp5_, 0, _data_->_tmp6_, files_view_details_column_get_resolution_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp7_ = g_file_read_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error0_);
		_data_->_tmp4_ = _data_->_tmp7_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp8_ = _data_->_tmp4_;
		_data_->_tmp4_ = NULL;
		_g_object_unref0 (_data_->stream);
		_data_->stream = _data_->_tmp8_;
		_data_->_tmp9_ = _data_->stream;
		if (_data_->_tmp9_ == NULL) {
			g_error ("DetailsColumn.vala:288: Could not read image file's size data");
		} else {
			_data_->_tmp10_ = _data_->stream;
			_data_->_tmp11_ = _data_->self->priv->cancellable;
			_data_->_state_ = 2;
			gdk_pixbuf_new_from_stream_async ((GInputStream*) _data_->_tmp10_, _data_->_tmp11_, files_view_details_column_get_resolution_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp12_ = (GdkPixbuf*) gdk_pixbuf_new_from_stream_finish (_data_->_res_, &_data_->_inner_error0_);
			_data_->pixbuf = _data_->_tmp12_;
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->_tmp4_);
				goto __catch0_g_error;
			}
			_data_->_tmp13_ = _data_->pixbuf;
			_data_->goffile->width = gdk_pixbuf_get_width (_data_->_tmp13_);
			_data_->_tmp14_ = _data_->pixbuf;
			_data_->goffile->height = gdk_pixbuf_get_height (_data_->_tmp14_);
			_data_->_tmp15_ = g_strdup_printf ("%i", _data_->goffile->width);
			_data_->_tmp16_ = _data_->_tmp15_;
			_data_->_tmp17_ = g_strconcat (_data_->_tmp16_, " × ", NULL);
			_data_->_tmp18_ = _data_->_tmp17_;
			_data_->_tmp19_ = g_strdup_printf ("%i", _data_->goffile->height);
			_data_->_tmp20_ = _data_->_tmp19_;
			_data_->_tmp21_ = g_strconcat (_data_->_tmp18_, _data_->_tmp20_, NULL);
			_data_->_tmp22_ = _data_->_tmp21_;
			_data_->_tmp23_ = g_strconcat (_data_->_tmp22_, " px", NULL);
			_g_free0 (_data_->resolution);
			_data_->resolution = _data_->_tmp23_;
			_g_free0 (_data_->_tmp22_);
			_g_free0 (_data_->_tmp20_);
			_g_free0 (_data_->_tmp18_);
			_g_free0 (_data_->_tmp16_);
			_g_object_unref0 (_data_->pixbuf);
		}
		_g_object_unref0 (_data_->_tmp4_);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp24_ = _data_->e;
		_data_->_tmp25_ = _data_->_tmp24_->message;
		g_warning ("DetailsColumn.vala:296: Error loading image resolution in PropertiesWi" \
"ndow: %s", _data_->_tmp25_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_free0 (_data_->resolution);
		_g_object_unref0 (_data_->file);
		_g_object_unref0 (_data_->stream);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	{
		_data_->_tmp26_ = _data_->stream;
		g_input_stream_close ((GInputStream*) _data_->_tmp26_, NULL, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		_data_->_vala1_e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp27_ = _data_->_vala1_e;
		_data_->_tmp28_ = _data_->_tmp27_->message;
		g_debug ("DetailsColumn.vala:302: Error closing stream in get_resolution: %s", _data_->_tmp28_);
		_g_error_free0 (_data_->_vala1_e);
	}
	__finally1:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_free0 (_data_->resolution);
		_g_object_unref0 (_data_->file);
		_g_object_unref0 (_data_->stream);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp29_ = _data_->self->priv->resolution_value;
	_data_->_tmp30_ = _data_->resolution;
	gtk_label_set_label (_data_->_tmp29_, _data_->_tmp30_);
	_g_free0 (_data_->resolution);
	_g_object_unref0 (_data_->file);
	_g_object_unref0 (_data_->stream);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static gchar*
files_view_details_column_resolution (FilesViewDetailsColumn* self,
                                      FilesFile* file)
{
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (file != NULL, NULL);
	if (file->width > 0) {
		gchar* _tmp0_;
		gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		_tmp0_ = g_strdup_printf ("%i", file->width);
		_tmp1_ = _tmp0_;
		_tmp2_ = g_strconcat (_tmp1_, " × ", NULL);
		_tmp3_ = _tmp2_;
		_tmp4_ = g_strdup_printf ("%i", file->height);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_strconcat (_tmp3_, _tmp5_, NULL);
		_tmp7_ = _tmp6_;
		_tmp8_ = g_strconcat (_tmp7_, " px", NULL);
		_tmp9_ = _tmp8_;
		_g_free0 (_tmp7_);
		_g_free0 (_tmp5_);
		_g_free0 (_tmp3_);
		_g_free0 (_tmp1_);
		result = _tmp9_;
		return result;
	} else {
		gchar* _tmp10_;
		files_view_details_column_get_resolution (self, file, NULL, NULL);
		_tmp10_ = g_strdup (_ ("Loading…"));
		result = _tmp10_;
		return result;
	}
}

gchar*
files_view_details_column_get_common_trash_orig (FilesFile* file)
{
	GFile* loc = NULL;
	GFileInfo* _tmp0_;
	const gchar* _tmp1_;
	GFile* _tmp2_;
	gchar* path = NULL;
	GFile* _tmp3_;
	gchar* result;
	g_return_val_if_fail (file != NULL, NULL);
	_tmp0_ = file->info;
	_tmp1_ = g_file_info_get_attribute_byte_string (_tmp0_, G_FILE_ATTRIBUTE_TRASH_ORIG_PATH);
	_tmp2_ = files_view_details_column_get_parent_loc (_tmp1_);
	loc = _tmp2_;
	path = NULL;
	_tmp3_ = loc;
	if (_tmp3_ == NULL) {
		gchar* _tmp4_;
		_tmp4_ = g_strdup ("/");
		_g_free0 (path);
		path = _tmp4_;
	} else {
		GFile* _tmp5_;
		gchar* _tmp6_;
		_tmp5_ = loc;
		_tmp6_ = g_file_get_parse_name (_tmp5_);
		_g_free0 (path);
		path = _tmp6_;
	}
	result = path;
	_g_object_unref0 (loc);
	return result;
}

GFile*
files_view_details_column_get_parent_loc (const gchar* path)
{
	GFile* loc = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* result;
	g_return_val_if_fail (path != NULL, NULL);
	_tmp0_ = g_file_new_for_path (path);
	loc = _tmp0_;
	_tmp1_ = g_file_get_parent (loc);
	result = _tmp1_;
	_g_object_unref0 (loc);
	return result;
}

gint
files_view_details_column_get_width (FilesViewDetailsColumn* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE + (2 * FILES_VIEW_DETAILS_COLUMN_PREVIEW_H_MARGIN);
	return result;
}

FilesFile*
files_view_details_column_get_file (FilesViewDetailsColumn* self)
{
	FilesFile* result;
	FilesFile* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_file;
	result = _tmp0_;
	return result;
}

static void
files_view_details_column_set_file (FilesViewDetailsColumn* self,
                                    FilesFile* value)
{
	FilesFile* old_value;
	g_return_if_fail (self != NULL);
	old_value = files_view_details_column_get_file (self);
	if (old_value != value) {
		FilesFile* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_file);
		self->priv->_file = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, files_view_details_column_properties[FILES_VIEW_DETAILS_COLUMN_FILE_PROPERTY]);
	}
}

FilesAbstractDirectoryView*
files_view_details_column_get_view (FilesViewDetailsColumn* self)
{
	FilesAbstractDirectoryView* result;
	FilesAbstractDirectoryView* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_view;
	result = _tmp0_;
	return result;
}

static void
files_view_details_column_set_view (FilesViewDetailsColumn* self,
                                    FilesAbstractDirectoryView* value)
{
	FilesAbstractDirectoryView* old_value;
	g_return_if_fail (self != NULL);
	old_value = files_view_details_column_get_view (self);
	if (old_value != value) {
		FilesAbstractDirectoryView* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_view);
		self->priv->_view = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, files_view_details_column_properties[FILES_VIEW_DETAILS_COLUMN_VIEW_PROPERTY]);
	}
}

static void
_g_object_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}

static inline void
_g_list_free__g_object_unref0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
}

static void
_files_view_details_column___lambda41_ (FilesViewDetailsColumn* self)
{
	GList* the_file_in_a_list = NULL;
	FilesFile* _tmp0_;
	FilesFile* _tmp1_;
	GList* _tmp2_;
	FilesAbstractDirectoryView* _tmp3_;
	GtkWindow* _tmp4_;
	GtkWindow* _tmp5_;
	FilesViewPropertiesWindow* _tmp6_;
	FilesViewPropertiesWindow* _tmp7_;
	the_file_in_a_list = NULL;
	_tmp0_ = self->priv->_file;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	the_file_in_a_list = g_list_append (the_file_in_a_list, _tmp1_);
	_tmp2_ = the_file_in_a_list;
	_tmp3_ = self->priv->_view;
	_tmp4_ = files_get_active_window ();
	_tmp5_ = _tmp4_;
	_tmp6_ = files_view_properties_window_new (_tmp2_, _tmp3_, _tmp5_);
	g_object_ref_sink (_tmp6_);
	_tmp7_ = _tmp6_;
	_g_object_unref0 (_tmp7_);
	_g_object_unref0 (_tmp5_);
	(the_file_in_a_list == NULL) ? NULL : (the_file_in_a_list = (_g_list_free__g_object_unref0_ (the_file_in_a_list), NULL));
}

static void
__files_view_details_column___lambda41__gtk_button_clicked (GtkButton* _sender,
                                                            gpointer self)
{
	_files_view_details_column___lambda41_ ((FilesViewDetailsColumn*) self);
}

static GObject *
files_view_details_column_constructor (GType type,
                                       guint n_construct_properties,
                                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	FilesViewDetailsColumn * self;
	guint64 file_real_size = 0ULL;
	FilesFile* _tmp0_;
	GtkGrid* info_grid = NULL;
	GtkGrid* _tmp1_ = NULL;
	GtkImage* file_image = NULL;
	GtkImage* _tmp2_ = NULL;
	GtkImage* _tmp3_;
	GtkStyleContext* _tmp4_;
	GtkImage* _tmp5_;
	GtkStyleContext* _tmp6_;
	GtkTextView* file_text = NULL;
	GtkTextView* _tmp7_ = NULL;
	GdkPixbuf* ico_pix = NULL;
	FilesFile* _tmp8_;
	GdkPixbuf* _tmp9_;
	GdkPixbuf* _tmp10_;
	gboolean _tmp14_ = FALSE;
	FilesFile* _tmp15_;
	GtkLabel* name_key_label = NULL;
	GtkLabel* _tmp64_;
	GtkLabel* name_value = NULL;
	FilesFile* _tmp65_;
	const gchar* _tmp66_;
	GtkLabel* _tmp67_;
	GtkLabel* size_key_label = NULL;
	GtkLabel* _tmp68_;
	GtkSpinner* spinner = NULL;
	GtkSpinner* _tmp69_ = NULL;
	GtkLabel* size_value = NULL;
	GtkLabel* _tmp70_;
	GtkLabel* _tmp71_;
	gchar* _tmp72_;
	gchar* _tmp73_;
	GtkGrid* _tmp74_;
	GtkLabel* _tmp75_;
	GtkGrid* _tmp76_;
	GtkLabel* _tmp77_;
	GtkLabel* _tmp78_;
	GtkGrid* _tmp79_;
	GtkLabel* _tmp80_;
	GtkGrid* _tmp81_;
	GtkSpinner* _tmp82_;
	GtkLabel* _tmp83_;
	GtkGrid* _tmp84_;
	GtkLabel* _tmp85_;
	GtkLabel* _tmp86_;
	gchar* time_created = NULL;
	FilesFile* _tmp87_;
	GFileInfo* _tmp88_;
	FilesPreferences* _tmp89_;
	FilesPreferences* _tmp90_;
	FilesDateFormatMode _tmp91_;
	FilesDateFormatMode _tmp92_;
	gchar* _tmp93_;
	gchar* _tmp94_;
	gint n = 0;
	const gchar* _tmp95_;
	gchar* time_modified = NULL;
	FilesFile* _tmp105_;
	GFileInfo* _tmp106_;
	FilesPreferences* _tmp107_;
	FilesPreferences* _tmp108_;
	FilesDateFormatMode _tmp109_;
	FilesDateFormatMode _tmp110_;
	gchar* _tmp111_;
	gchar* _tmp112_;
	const gchar* _tmp113_;
	FilesFile* _tmp123_;
	gchar* ftype = NULL;
	FilesFile* _tmp142_;
	gchar* _tmp143_;
	GtkLabel* mimetype_key = NULL;
	GtkLabel* _tmp144_;
	GtkLabel* mimetype_value = NULL;
	const gchar* _tmp145_;
	GtkLabel* _tmp146_;
	GtkGrid* _tmp147_;
	GtkLabel* _tmp148_;
	GtkGrid* _tmp149_;
	GtkLabel* _tmp150_;
	GtkLabel* _tmp151_;
	gint _tmp152_;
	FilesFile* _tmp153_;
	FilesFile* _tmp165_;
	GFileInfo* _tmp166_;
	FilesFile* _tmp178_;
	GtkButton* more_info_button = NULL;
	GtkButton* _tmp191_ = NULL;
	GtkBox* box = NULL;
	GtkBox* _tmp192_ = NULL;
	GtkBox* _tmp200_;
	GtkGrid* _tmp201_;
	GtkBox* _tmp202_;
	GtkButton* _tmp203_;
	GtkScrolledWindow* scrolled = NULL;
	GtkBox* _tmp204_;
	GtkWidget* _tmp205_;
	GtkScrolledWindow* _tmp206_ = NULL;
	GtkScrolledWindow* _tmp207_;
	GtkButton* _tmp208_;
	GError* _inner_error0_ = NULL;
	parent_class = G_OBJECT_CLASS (files_view_details_column_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumn);
	_tmp0_ = self->priv->_file;
	file_real_size = files_view_properties_window_file_real_size (_tmp0_);
	_tmp1_ = (GtkGrid*) gtk_grid_new ();
	gtk_grid_set_column_spacing (_tmp1_, 6);
	gtk_grid_set_row_spacing (_tmp1_, 6);
	g_object_ref_sink (_tmp1_);
	info_grid = _tmp1_;
	_tmp2_ = (GtkImage*) gtk_image_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp2_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp2_, TRUE);
	gtk_widget_set_halign ((GtkWidget*) _tmp2_, GTK_ALIGN_CENTER);
	gtk_widget_set_valign ((GtkWidget*) _tmp2_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp2_);
	file_image = _tmp2_;
	_tmp3_ = file_image;
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
	gtk_style_context_add_class (_tmp4_, GRANITE_STYLE_CLASS_CARD);
	_tmp5_ = file_image;
	_tmp6_ = gtk_widget_get_style_context ((GtkWidget*) _tmp5_);
	gtk_style_context_add_class (_tmp6_, GRANITE_STYLE_CLASS_CHECKERBOARD);
	_tmp7_ = (GtkTextView*) gtk_text_view_new ();
	gtk_text_view_set_cursor_visible (_tmp7_, FALSE);
	gtk_text_view_set_editable (_tmp7_, FALSE);
	gtk_text_view_set_top_margin (_tmp7_, 12);
	gtk_text_view_set_bottom_margin (_tmp7_, 12);
	gtk_text_view_set_left_margin (_tmp7_, 12);
	gtk_text_view_set_right_margin (_tmp7_, 12);
	g_object_ref_sink (_tmp7_);
	file_text = _tmp7_;
	_tmp8_ = self->priv->_file;
	_tmp9_ = files_file_get_icon_pixbuf (_tmp8_, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE, gtk_widget_get_scale_factor ((GtkWidget*) self), FILES_FILE_ICON_FLAGS_NONE);
	ico_pix = _tmp9_;
	_tmp10_ = ico_pix;
	if (_tmp10_ != NULL) {
		GtkImage* _tmp11_;
		GdkPixbuf* _tmp12_;
		GtkImage* _tmp13_;
		_tmp11_ = file_image;
		_tmp12_ = ico_pix;
		g_object_set (_tmp11_, "gicon", (GIcon*) _tmp12_, NULL);
		_tmp13_ = file_image;
		gtk_image_set_pixel_size (_tmp13_, 48);
	}
	_tmp15_ = self->priv->_file;
	if (files_file_is_readable (_tmp15_)) {
		_tmp14_ = file_real_size <= ((guint64) FILES_VIEW_DETAILS_COLUMN_MAX_PREVIEW_FILE_SIZE);
	} else {
		_tmp14_ = FALSE;
	}
	if (_tmp14_) {
		gchar* filename = NULL;
		FilesFile* _tmp16_;
		GFile* _tmp17_;
		GFile* _tmp18_;
		gchar* _tmp19_;
		FilesFile* _tmp20_;
		_tmp16_ = self->priv->_file;
		_tmp17_ = files_file_get_location (_tmp16_);
		_tmp18_ = _tmp17_;
		_tmp19_ = g_file_get_path (_tmp18_);
		filename = _tmp19_;
		_tmp20_ = self->priv->_file;
		if (files_file_is_image (_tmp20_)) {
			GtkImage* _tmp21_;
			FilesFile* _tmp22_;
			GFile* _tmp23_;
			GFile* _tmp24_;
			GFileIcon* _tmp25_;
			GFileIcon* _tmp26_;
			GtkImage* _tmp27_;
			_tmp21_ = file_image;
			_tmp22_ = self->priv->_file;
			_tmp23_ = files_file_get_location (_tmp22_);
			_tmp24_ = _tmp23_;
			_tmp25_ = (GFileIcon*) g_file_icon_new (_tmp24_);
			_tmp26_ = _tmp25_;
			g_object_set (_tmp21_, "gicon", (GIcon*) _tmp26_, NULL);
			_g_object_unref0 (_tmp26_);
			_tmp27_ = file_image;
			gtk_image_set_pixel_size (_tmp27_, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE);
		} else {
			FilesFile* _tmp28_;
			_tmp28_ = self->priv->_file;
			if (files_file_is_pdf (_tmp28_)) {
				{
					gchar* _tmp29_ = NULL;
					const gchar* _tmp30_;
					gchar* _tmp31_;
					PopplerDocument* doc = NULL;
					PopplerDocument* _tmp32_;
					PopplerPage* page = NULL;
					PopplerDocument* _tmp33_;
					PopplerPage* _tmp34_;
					cairo_surface_t* surface = NULL;
					cairo_surface_t* _tmp35_;
					cairo_t* ctx = NULL;
					cairo_surface_t* _tmp36_;
					cairo_t* _tmp37_;
					cairo_t* _tmp38_;
					cairo_t* _tmp39_;
					cairo_t* _tmp40_;
					PopplerPage* _tmp41_;
					cairo_t* _tmp42_;
					cairo_t* _tmp43_;
					GdkPixbuf* pdf_pix = NULL;
					cairo_surface_t* _tmp44_;
					GdkPixbuf* _tmp45_;
					GtkImage* _tmp46_;
					GdkPixbuf* _tmp47_;
					_tmp30_ = filename;
					_tmp31_ = g_filename_to_uri (_tmp30_, NULL, &_inner_error0_);
					_tmp29_ = _tmp31_;
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						goto __catch0_g_error;
					}
					_tmp32_ = poppler_document_new_from_file (_tmp29_, NULL, &_inner_error0_);
					doc = _tmp32_;
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						_g_free0 (_tmp29_);
						goto __catch0_g_error;
					}
					_tmp33_ = doc;
					_tmp34_ = poppler_document_get_page (_tmp33_, 0);
					page = _tmp34_;
					_tmp35_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE);
					surface = _tmp35_;
					_tmp36_ = surface;
					_tmp37_ = cairo_create (_tmp36_);
					ctx = _tmp37_;
					_tmp38_ = ctx;
					cairo_set_source_rgb (_tmp38_, (gdouble) 255, (gdouble) 255, (gdouble) 255);
					_tmp39_ = ctx;
					cairo_paint (_tmp39_);
					_tmp40_ = ctx;
					cairo_scale (_tmp40_, 0.5, 0.5);
					_tmp41_ = page;
					_tmp42_ = ctx;
					poppler_page_render (_tmp41_, (cairo_t*) _tmp42_);
					_tmp43_ = ctx;
					cairo_restore (_tmp43_);
					_tmp44_ = surface;
					_tmp45_ = gdk_pixbuf_get_from_surface (_tmp44_, 0, 0, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE);
					pdf_pix = _tmp45_;
					_tmp46_ = file_image;
					_tmp47_ = pdf_pix;
					gtk_image_set_from_pixbuf (_tmp46_, _tmp47_);
					_g_object_unref0 (pdf_pix);
					_cairo_destroy0 (ctx);
					_cairo_surface_destroy0 (surface);
					_g_object_unref0 (page);
					_g_object_unref0 (doc);
					_g_free0 (_tmp29_);
				}
				goto __finally0;
				__catch0_g_error:
				{
					GError* e = NULL;
					GError* _tmp48_;
					const gchar* _tmp49_;
					e = _inner_error0_;
					_inner_error0_ = NULL;
					_tmp48_ = e;
					_tmp49_ = _tmp48_->message;
					g_warning ("DetailsColumn.vala:101: Error: %s\n", _tmp49_);
					_g_error_free0 (e);
				}
				__finally0:
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
					_g_free0 (filename);
					_g_object_unref0 (ico_pix);
					_g_object_unref0 (file_text);
					_g_object_unref0 (file_image);
					_g_object_unref0 (info_grid);
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
					g_clear_error (&_inner_error0_);
				}
			} else {
				FilesFile* _tmp50_;
				_tmp50_ = self->priv->_file;
				if (files_file_is_text (_tmp50_)) {
					{
						guint8* contents = NULL;
						gint contents_length1 = 0;
						gint _contents_size_ = 0;
						gchar* etag_out = NULL;
						FilesFile* _tmp51_;
						GFile* _tmp52_;
						GFile* _tmp53_;
						guint8* _tmp54_ = NULL;
						gsize _tmp55_ = 0;
						gchar* _tmp56_ = NULL;
						GtkTextBuffer* buffer = NULL;
						GtkTextView* _tmp57_;
						GtkTextBuffer* _tmp58_;
						GtkTextBuffer* _tmp59_;
						GtkTextBuffer* _tmp60_;
						guint8* _tmp61_;
						gint _tmp61__length1;
						self->priv->previewing_text = TRUE;
						_tmp51_ = self->priv->_file;
						_tmp52_ = files_file_get_location (_tmp51_);
						_tmp53_ = _tmp52_;
						g_file_load_contents (_tmp53_, NULL, &_tmp54_, &_tmp55_, &_tmp56_, &_inner_error0_);
						contents = (g_free (contents), NULL);
						contents = _tmp54_;
						contents_length1 = _tmp55_;
						_contents_size_ = contents_length1;
						_g_free0 (etag_out);
						etag_out = _tmp56_;
						if (G_UNLIKELY (_inner_error0_ != NULL)) {
							_g_free0 (etag_out);
							contents = (g_free (contents), NULL);
							goto __catch1_g_error;
						}
						_tmp57_ = file_text;
						_tmp58_ = gtk_text_view_get_buffer (_tmp57_);
						_tmp59_ = _g_object_ref0 (_tmp58_);
						buffer = _tmp59_;
						_tmp60_ = buffer;
						_tmp61_ = contents;
						_tmp61__length1 = contents_length1;
						gtk_text_buffer_set_text (_tmp60_, (const gchar*) _tmp61_, -1);
						_g_object_unref0 (buffer);
						_g_free0 (etag_out);
						contents = (g_free (contents), NULL);
					}
					goto __finally1;
					__catch1_g_error:
					{
						GError* e = NULL;
						GError* _tmp62_;
						const gchar* _tmp63_;
						e = _inner_error0_;
						_inner_error0_ = NULL;
						_tmp62_ = e;
						_tmp63_ = _tmp62_->message;
						g_warning ("DetailsColumn.vala:113: Error: %s\n", _tmp63_);
						_g_error_free0 (e);
					}
					__finally1:
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						_g_free0 (filename);
						_g_object_unref0 (ico_pix);
						_g_object_unref0 (file_text);
						_g_object_unref0 (file_image);
						_g_object_unref0 (info_grid);
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
						g_clear_error (&_inner_error0_);
					}
				}
			}
		}
		_g_free0 (filename);
	}
	_tmp64_ = files_make_key_label (_ ("Name:"));
	name_key_label = _tmp64_;
	_tmp65_ = self->priv->_file;
	_tmp66_ = files_file_get_display_name (_tmp65_);
	_tmp67_ = files_make_value_label (_tmp66_);
	name_value = _tmp67_;
	_tmp68_ = files_make_key_label (_ ("Size:"));
	size_key_label = _tmp68_;
	_tmp69_ = (GtkSpinner*) gtk_spinner_new ();
	gtk_widget_set_halign ((GtkWidget*) _tmp69_, GTK_ALIGN_START);
	g_object_ref_sink (_tmp69_);
	spinner = _tmp69_;
	_tmp70_ = files_make_value_label ("");
	size_value = _tmp70_;
	_tmp71_ = size_value;
	_tmp72_ = g_format_size_full (file_real_size, G_FORMAT_SIZE_DEFAULT);
	_tmp73_ = _tmp72_;
	gtk_label_set_label (_tmp71_, _tmp73_);
	_g_free0 (_tmp73_);
	_tmp74_ = info_grid;
	_tmp75_ = name_key_label;
	gtk_grid_attach (_tmp74_, (GtkWidget*) _tmp75_, 0, 1, 1, 1);
	_tmp76_ = info_grid;
	_tmp77_ = name_value;
	_tmp78_ = name_key_label;
	gtk_grid_attach_next_to (_tmp76_, (GtkWidget*) _tmp77_, (GtkWidget*) _tmp78_, GTK_POS_RIGHT, 1, 1);
	_tmp79_ = info_grid;
	_tmp80_ = size_key_label;
	gtk_grid_attach (_tmp79_, (GtkWidget*) _tmp80_, 0, 2, 1, 1);
	_tmp81_ = info_grid;
	_tmp82_ = spinner;
	_tmp83_ = size_key_label;
	gtk_grid_attach_next_to (_tmp81_, (GtkWidget*) _tmp82_, (GtkWidget*) _tmp83_, GTK_POS_RIGHT, 1, 1);
	_tmp84_ = info_grid;
	_tmp85_ = size_value;
	_tmp86_ = size_key_label;
	gtk_grid_attach_next_to (_tmp84_, (GtkWidget*) _tmp85_, (GtkWidget*) _tmp86_, GTK_POS_RIGHT, 1, 1);
	_tmp87_ = self->priv->_file;
	_tmp88_ = _tmp87_->info;
	_tmp89_ = files_preferences_get_default ();
	_tmp90_ = _tmp89_;
	_tmp91_ = files_preferences_get_date_format (_tmp90_);
	_tmp92_ = _tmp91_;
	_tmp93_ = files_file_utils_get_formatted_time_attribute_from_info (_tmp88_, G_FILE_ATTRIBUTE_TIME_CREATED, _tmp92_, FALSE);
	_tmp94_ = _tmp93_;
	_g_object_unref0 (_tmp90_);
	time_created = _tmp94_;
	n = 5;
	_tmp95_ = time_created;
	if (g_strcmp0 (_tmp95_, "") != 0) {
		GtkLabel* key_label = NULL;
		GtkLabel* _tmp96_;
		GtkLabel* value_label = NULL;
		const gchar* _tmp97_;
		GtkLabel* _tmp98_;
		GtkGrid* _tmp99_;
		GtkLabel* _tmp100_;
		GtkGrid* _tmp101_;
		GtkLabel* _tmp102_;
		GtkLabel* _tmp103_;
		gint _tmp104_;
		_tmp96_ = files_make_key_label (_ ("Created:"));
		key_label = _tmp96_;
		_tmp97_ = time_created;
		_tmp98_ = files_make_value_label (_tmp97_);
		value_label = _tmp98_;
		_tmp99_ = info_grid;
		_tmp100_ = key_label;
		gtk_grid_attach (_tmp99_, (GtkWidget*) _tmp100_, 0, n, 1, 1);
		_tmp101_ = info_grid;
		_tmp102_ = value_label;
		_tmp103_ = key_label;
		gtk_grid_attach_next_to (_tmp101_, (GtkWidget*) _tmp102_, (GtkWidget*) _tmp103_, GTK_POS_RIGHT, 3, 1);
		_tmp104_ = n;
		n = _tmp104_ + 1;
		_g_object_unref0 (value_label);
		_g_object_unref0 (key_label);
	}
	_tmp105_ = self->priv->_file;
	_tmp106_ = _tmp105_->info;
	_tmp107_ = files_preferences_get_default ();
	_tmp108_ = _tmp107_;
	_tmp109_ = files_preferences_get_date_format (_tmp108_);
	_tmp110_ = _tmp109_;
	_tmp111_ = files_file_utils_get_formatted_time_attribute_from_info (_tmp106_, G_FILE_ATTRIBUTE_TIME_MODIFIED, _tmp110_, FALSE);
	_tmp112_ = _tmp111_;
	_g_object_unref0 (_tmp108_);
	time_modified = _tmp112_;
	_tmp113_ = time_modified;
	if (g_strcmp0 (_tmp113_, "") != 0) {
		GtkLabel* key_label = NULL;
		GtkLabel* _tmp114_;
		GtkLabel* value_label = NULL;
		const gchar* _tmp115_;
		GtkLabel* _tmp116_;
		GtkGrid* _tmp117_;
		GtkLabel* _tmp118_;
		GtkGrid* _tmp119_;
		GtkLabel* _tmp120_;
		GtkLabel* _tmp121_;
		gint _tmp122_;
		_tmp114_ = files_make_key_label (_ ("Modified:"));
		key_label = _tmp114_;
		_tmp115_ = time_modified;
		_tmp116_ = files_make_value_label (_tmp115_);
		value_label = _tmp116_;
		_tmp117_ = info_grid;
		_tmp118_ = key_label;
		gtk_grid_attach (_tmp117_, (GtkWidget*) _tmp118_, 0, n, 1, 1);
		_tmp119_ = info_grid;
		_tmp120_ = value_label;
		_tmp121_ = key_label;
		gtk_grid_attach_next_to (_tmp119_, (GtkWidget*) _tmp120_, (GtkWidget*) _tmp121_, GTK_POS_RIGHT, 3, 1);
		_tmp122_ = n;
		n = _tmp122_ + 1;
		_g_object_unref0 (value_label);
		_g_object_unref0 (key_label);
	}
	_tmp123_ = self->priv->_file;
	if (files_file_is_trashed (_tmp123_)) {
		gchar* deletion_date = NULL;
		FilesFile* _tmp124_;
		GFileInfo* _tmp125_;
		FilesPreferences* _tmp126_;
		FilesPreferences* _tmp127_;
		FilesDateFormatMode _tmp128_;
		FilesDateFormatMode _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
		const gchar* _tmp132_;
		_tmp124_ = self->priv->_file;
		_tmp125_ = _tmp124_->info;
		_tmp126_ = files_preferences_get_default ();
		_tmp127_ = _tmp126_;
		_tmp128_ = files_preferences_get_date_format (_tmp127_);
		_tmp129_ = _tmp128_;
		_tmp130_ = files_file_utils_get_formatted_time_attribute_from_info (_tmp125_, G_FILE_ATTRIBUTE_TRASH_DELETION_DATE, _tmp129_, FALSE);
		_tmp131_ = _tmp130_;
		_g_object_unref0 (_tmp127_);
		deletion_date = _tmp131_;
		_tmp132_ = deletion_date;
		if (g_strcmp0 (_tmp132_, "") != 0) {
			GtkLabel* key_label = NULL;
			GtkLabel* _tmp133_;
			GtkLabel* value_label = NULL;
			const gchar* _tmp134_;
			GtkLabel* _tmp135_;
			GtkGrid* _tmp136_;
			GtkLabel* _tmp137_;
			GtkGrid* _tmp138_;
			GtkLabel* _tmp139_;
			GtkLabel* _tmp140_;
			gint _tmp141_;
			_tmp133_ = files_make_key_label (_ ("Deleted:"));
			key_label = _tmp133_;
			_tmp134_ = deletion_date;
			_tmp135_ = files_make_value_label (_tmp134_);
			value_label = _tmp135_;
			_tmp136_ = info_grid;
			_tmp137_ = key_label;
			gtk_grid_attach (_tmp136_, (GtkWidget*) _tmp137_, 0, n, 1, 1);
			_tmp138_ = info_grid;
			_tmp139_ = value_label;
			_tmp140_ = key_label;
			gtk_grid_attach_next_to (_tmp138_, (GtkWidget*) _tmp139_, (GtkWidget*) _tmp140_, GTK_POS_RIGHT, 3, 1);
			_tmp141_ = n;
			n = _tmp141_ + 1;
			_g_object_unref0 (value_label);
			_g_object_unref0 (key_label);
		}
		_g_free0 (deletion_date);
	}
	_tmp142_ = self->priv->_file;
	_tmp143_ = files_view_details_column_filetype (_tmp142_);
	ftype = _tmp143_;
	_tmp144_ = files_make_key_label (_ ("Media type:"));
	mimetype_key = _tmp144_;
	_tmp145_ = ftype;
	_tmp146_ = files_make_value_label (_tmp145_);
	mimetype_value = _tmp146_;
	_tmp147_ = info_grid;
	_tmp148_ = mimetype_key;
	gtk_grid_attach (_tmp147_, (GtkWidget*) _tmp148_, 0, n, 1, 1);
	_tmp149_ = info_grid;
	_tmp150_ = mimetype_value;
	_tmp151_ = mimetype_key;
	gtk_grid_attach_next_to (_tmp149_, (GtkWidget*) _tmp150_, (GtkWidget*) _tmp151_, GTK_POS_RIGHT, 3, 1);
	_tmp152_ = n;
	n = _tmp152_ + 1;
	_tmp153_ = self->priv->_file;
	if (files_file_is_image (_tmp153_)) {
		GtkLabel* resolution_key = NULL;
		GtkLabel* _tmp154_;
		FilesFile* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		GtkLabel* _tmp158_;
		GtkGrid* _tmp159_;
		GtkLabel* _tmp160_;
		GtkGrid* _tmp161_;
		GtkLabel* _tmp162_;
		GtkLabel* _tmp163_;
		gint _tmp164_;
		_tmp154_ = files_make_key_label (_ ("Resolution:"));
		resolution_key = _tmp154_;
		_tmp155_ = self->priv->_file;
		_tmp156_ = files_view_details_column_resolution (self, _tmp155_);
		_tmp157_ = _tmp156_;
		_tmp158_ = files_make_value_label (_tmp157_);
		_g_object_unref0 (self->priv->resolution_value);
		self->priv->resolution_value = _tmp158_;
		_g_free0 (_tmp157_);
		_tmp159_ = info_grid;
		_tmp160_ = resolution_key;
		gtk_grid_attach (_tmp159_, (GtkWidget*) _tmp160_, 0, n, 1, 1);
		_tmp161_ = info_grid;
		_tmp162_ = self->priv->resolution_value;
		_tmp163_ = resolution_key;
		gtk_grid_attach_next_to (_tmp161_, (GtkWidget*) _tmp162_, (GtkWidget*) _tmp163_, GTK_POS_RIGHT, 3, 1);
		_tmp164_ = n;
		n = _tmp164_ + 1;
		_g_object_unref0 (resolution_key);
	}
	_tmp165_ = self->priv->_file;
	_tmp166_ = _tmp165_->info;
	if (g_file_info_get_attribute_boolean (_tmp166_, G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK)) {
		GtkLabel* key_label = NULL;
		GtkLabel* _tmp167_;
		GtkLabel* value_label = NULL;
		FilesFile* _tmp168_;
		GFileInfo* _tmp169_;
		const gchar* _tmp170_;
		GtkLabel* _tmp171_;
		GtkGrid* _tmp172_;
		GtkLabel* _tmp173_;
		GtkGrid* _tmp174_;
		GtkLabel* _tmp175_;
		GtkLabel* _tmp176_;
		gint _tmp177_;
		_tmp167_ = files_make_key_label (_ ("Target:"));
		key_label = _tmp167_;
		_tmp168_ = self->priv->_file;
		_tmp169_ = _tmp168_->info;
		_tmp170_ = g_file_info_get_attribute_byte_string (_tmp169_, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET);
		_tmp171_ = files_make_value_label (_tmp170_);
		value_label = _tmp171_;
		_tmp172_ = info_grid;
		_tmp173_ = key_label;
		gtk_grid_attach (_tmp172_, (GtkWidget*) _tmp173_, 0, n, 1, 1);
		_tmp174_ = info_grid;
		_tmp175_ = value_label;
		_tmp176_ = key_label;
		gtk_grid_attach_next_to (_tmp174_, (GtkWidget*) _tmp175_, (GtkWidget*) _tmp176_, GTK_POS_RIGHT, 3, 1);
		_tmp177_ = n;
		n = _tmp177_ + 1;
		_g_object_unref0 (value_label);
		_g_object_unref0 (key_label);
	}
	_tmp178_ = self->priv->_file;
	if (files_file_is_trashed (_tmp178_)) {
		GtkLabel* key_label = NULL;
		GtkLabel* _tmp179_;
		GtkLabel* value_label = NULL;
		FilesFile* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
		GtkLabel* _tmp183_;
		GtkLabel* _tmp184_;
		GtkGrid* _tmp185_;
		GtkLabel* _tmp186_;
		GtkGrid* _tmp187_;
		GtkLabel* _tmp188_;
		GtkLabel* _tmp189_;
		gint _tmp190_;
		_tmp179_ = files_make_key_label (_ ("Original Location:"));
		key_label = _tmp179_;
		_tmp180_ = self->priv->_file;
		_tmp181_ = files_view_details_column_original_location (_tmp180_);
		_tmp182_ = _tmp181_;
		_tmp183_ = files_make_value_label (_tmp182_);
		_tmp184_ = _tmp183_;
		_g_free0 (_tmp182_);
		value_label = _tmp184_;
		_tmp185_ = info_grid;
		_tmp186_ = key_label;
		gtk_grid_attach (_tmp185_, (GtkWidget*) _tmp186_, 0, n, 1, 1);
		_tmp187_ = info_grid;
		_tmp188_ = value_label;
		_tmp189_ = key_label;
		gtk_grid_attach_next_to (_tmp187_, (GtkWidget*) _tmp188_, (GtkWidget*) _tmp189_, GTK_POS_RIGHT, 3, 1);
		_tmp190_ = n;
		n = _tmp190_ + 1;
		_g_object_unref0 (value_label);
		_g_object_unref0 (key_label);
	}
	_tmp191_ = (GtkButton*) gtk_button_new_with_label (_ ("Properties…"));
	gtk_widget_set_halign ((GtkWidget*) _tmp191_, GTK_ALIGN_END);
	g_object_ref_sink (_tmp191_);
	more_info_button = _tmp191_;
	_tmp192_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	gtk_widget_set_halign ((GtkWidget*) _tmp192_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp192_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp192_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp192_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp192_, 12);
	g_object_ref_sink (_tmp192_);
	box = _tmp192_;
	if (self->priv->previewing_text) {
		GtkScrolledWindow* text_window = NULL;
		GtkTextView* _tmp193_;
		GtkWidget* _tmp194_;
		GtkScrolledWindow* _tmp195_ = NULL;
		GtkBox* _tmp196_;
		GtkScrolledWindow* _tmp197_;
		_tmp193_ = file_text;
		_tmp194_ = _g_object_ref0 ((GtkWidget*) _tmp193_);
		_tmp195_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
		g_object_set ((GtkContainer*) _tmp195_, "child", _tmp194_, NULL);
		_g_object_unref0 (_tmp194_);
		g_object_set ((GtkWidget*) _tmp195_, "width-request", FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE, NULL);
		g_object_set ((GtkWidget*) _tmp195_, "height-request", FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE, NULL);
		gtk_scrolled_window_set_max_content_height (_tmp195_, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE);
		gtk_scrolled_window_set_max_content_width (_tmp195_, FILES_VIEW_DETAILS_COLUMN_PREVIEW_SIZE);
		g_object_ref_sink (_tmp195_);
		text_window = _tmp195_;
		_tmp196_ = box;
		_tmp197_ = text_window;
		gtk_container_add ((GtkContainer*) _tmp196_, (GtkWidget*) _tmp197_);
		_g_object_unref0 (text_window);
	} else {
		GtkBox* _tmp198_;
		GtkImage* _tmp199_;
		_tmp198_ = box;
		_tmp199_ = file_image;
		gtk_container_add ((GtkContainer*) _tmp198_, (GtkWidget*) _tmp199_);
	}
	_tmp200_ = box;
	_tmp201_ = info_grid;
	gtk_container_add ((GtkContainer*) _tmp200_, (GtkWidget*) _tmp201_);
	_tmp202_ = box;
	_tmp203_ = more_info_button;
	gtk_container_add ((GtkContainer*) _tmp202_, (GtkWidget*) _tmp203_);
	_tmp204_ = box;
	_tmp205_ = _g_object_ref0 ((GtkWidget*) _tmp204_);
	_tmp206_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
	g_object_set ((GtkContainer*) _tmp206_, "child", _tmp205_, NULL);
	_g_object_unref0 (_tmp205_);
	gtk_scrolled_window_set_propagate_natural_height (_tmp206_, TRUE);
	g_object_set (_tmp206_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	g_object_ref_sink (_tmp206_);
	scrolled = _tmp206_;
	_tmp207_ = scrolled;
	g_object_set ((GtkContainer*) self, "child", (GtkWidget*) _tmp207_, NULL);
	gtk_widget_show_all ((GtkWidget*) self);
	_tmp208_ = more_info_button;
	g_signal_connect_object (_tmp208_, "clicked", (GCallback) __files_view_details_column___lambda41__gtk_button_clicked, self, 0);
	_g_object_unref0 (scrolled);
	_g_object_unref0 (box);
	_g_object_unref0 (more_info_button);
	_g_object_unref0 (mimetype_value);
	_g_object_unref0 (mimetype_key);
	_g_free0 (ftype);
	_g_free0 (time_modified);
	_g_free0 (time_created);
	_g_object_unref0 (size_value);
	_g_object_unref0 (spinner);
	_g_object_unref0 (size_key_label);
	_g_object_unref0 (name_value);
	_g_object_unref0 (name_key_label);
	_g_object_unref0 (ico_pix);
	_g_object_unref0 (file_text);
	_g_object_unref0 (file_image);
	_g_object_unref0 (info_grid);
	return obj;
}

static void
files_view_details_column_class_init (FilesViewDetailsColumnClass * klass,
                                      gpointer klass_data)
{
	files_view_details_column_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &FilesViewDetailsColumn_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_files_view_details_column_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_files_view_details_column_set_property;
	G_OBJECT_CLASS (klass)->constructor = files_view_details_column_constructor;
	G_OBJECT_CLASS (klass)->finalize = files_view_details_column_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), FILES_VIEW_DETAILS_COLUMN_WIDTH_PROPERTY, files_view_details_column_properties[FILES_VIEW_DETAILS_COLUMN_WIDTH_PROPERTY] = g_param_spec_int ("width", "width", "width", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FILES_VIEW_DETAILS_COLUMN_FILE_PROPERTY, files_view_details_column_properties[FILES_VIEW_DETAILS_COLUMN_FILE_PROPERTY] = g_param_spec_object ("file", "file", "file", FILES_TYPE_FILE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FILES_VIEW_DETAILS_COLUMN_VIEW_PROPERTY, files_view_details_column_properties[FILES_VIEW_DETAILS_COLUMN_VIEW_PROPERTY] = g_param_spec_object ("view", "view", "view", FILES_TYPE_ABSTRACT_DIRECTORY_VIEW, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}

static void
files_view_details_column_instance_init (FilesViewDetailsColumn * self,
                                         gpointer klass)
{
	self->priv = files_view_details_column_get_instance_private (self);
	self->priv->previewing_text = FALSE;
}

static void
files_view_details_column_finalize (GObject * obj)
{
	FilesViewDetailsColumn * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumn);
	_g_object_unref0 (self->priv->_file);
	_g_object_unref0 (self->priv->_view);
	_g_object_unref0 (self->priv->cancellable);
	_g_object_unref0 (self->priv->resolution_value);
	G_OBJECT_CLASS (files_view_details_column_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
files_view_details_column_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (FilesViewDetailsColumnClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) files_view_details_column_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FilesViewDetailsColumn), 0, (GInstanceInitFunc) files_view_details_column_instance_init, NULL };
	GType files_view_details_column_type_id;
	files_view_details_column_type_id = g_type_register_static (gtk_bin_get_type (), "FilesViewDetailsColumn", &g_define_type_info, 0);
	FilesViewDetailsColumn_private_offset = g_type_add_instance_private (files_view_details_column_type_id, sizeof (FilesViewDetailsColumnPrivate));
	return files_view_details_column_type_id;
}

GType
files_view_details_column_get_type (void)
{
	static volatile gsize files_view_details_column_type_id__once = 0;
	if (g_once_init_enter (&files_view_details_column_type_id__once)) {
		GType files_view_details_column_type_id;
		files_view_details_column_type_id = files_view_details_column_get_type_once ();
		g_once_init_leave (&files_view_details_column_type_id__once, files_view_details_column_type_id);
	}
	return files_view_details_column_type_id__once;
}

static void
_vala_files_view_details_column_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	FilesViewDetailsColumn * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumn);
	switch (property_id) {
		case FILES_VIEW_DETAILS_COLUMN_WIDTH_PROPERTY:
		g_value_set_int (value, files_view_details_column_get_width (self));
		break;
		case FILES_VIEW_DETAILS_COLUMN_FILE_PROPERTY:
		g_value_set_object (value, files_view_details_column_get_file (self));
		break;
		case FILES_VIEW_DETAILS_COLUMN_VIEW_PROPERTY:
		g_value_set_object (value, files_view_details_column_get_view (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_files_view_details_column_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	FilesViewDetailsColumn * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FILES_VIEW_TYPE_DETAILS_COLUMN, FilesViewDetailsColumn);
	switch (property_id) {
		case FILES_VIEW_DETAILS_COLUMN_FILE_PROPERTY:
		files_view_details_column_set_file (self, g_value_get_object (value));
		break;
		case FILES_VIEW_DETAILS_COLUMN_VIEW_PROPERTY:
		files_view_details_column_set_view (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

