/* Resources.c generated by valac 0.56.19, the Vala compiler
 * generated from Resources.vala, do not modify */

#include "pantheon-files-core.h"
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _g_free0(var) (var = (g_free (var), NULL))

const gchar* FILES_SKIP_IMAGES[3] = {"image/svg+xml", "image/tiff", "image/jp2"};

static gchar*
string_delimit (const gchar* self,
                const gchar* delimiters,
                gchar new_delimiter)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (delimiters != NULL, NULL);
	_tmp0_ = g_strdup (self);
	_result_ = _tmp0_;
	g_strdelimit (_result_, delimiters, new_delimiter);
	result = _result_;
	return result;
}

static gchar*
string_chomp (const gchar* self)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = g_strdup (self);
	_result_ = _tmp0_;
	g_strchomp (_result_);
	result = _result_;
	return result;
}

gchar*
files_protocol_to_name (const gchar* protocol)
{
	gchar* s = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	GQuark _tmp7_ = 0U;
	static GQuark _tmp6_label0 = 0;
	static GQuark _tmp6_label1 = 0;
	static GQuark _tmp6_label2 = 0;
	static GQuark _tmp6_label3 = 0;
	static GQuark _tmp6_label4 = 0;
	static GQuark _tmp6_label5 = 0;
	static GQuark _tmp6_label6 = 0;
	static GQuark _tmp6_label7 = 0;
	static GQuark _tmp6_label8 = 0;
	static GQuark _tmp6_label9 = 0;
	static GQuark _tmp6_label10 = 0;
	static GQuark _tmp6_label11 = 0;
	static GQuark _tmp6_label12 = 0;
	static GQuark _tmp6_label13 = 0;
	gchar* result;
	g_return_val_if_fail (protocol != NULL, NULL);
	_tmp0_ = string_delimit (protocol, ":/", ' ');
	_tmp1_ = _tmp0_;
	_tmp2_ = string_chomp (_tmp1_);
	_tmp3_ = _tmp2_;
	_g_free0 (_tmp1_);
	s = _tmp3_;
	_tmp4_ = s;
	_tmp5_ = _tmp4_;
	_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
	if (_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("recent")))) {
		switch (0) {
			default:
			{
				gchar* _tmp8_;
				_tmp8_ = g_strdup (_ (FILES_PROTOCOL_NAME_RECENT));
				result = _tmp8_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label1) ? _tmp6_label1 : (_tmp6_label1 = g_quark_from_static_string ("trash")))) {
		switch (0) {
			default:
			{
				gchar* _tmp9_;
				_tmp9_ = g_strdup (_ (FILES_PROTOCOL_NAME_TRASH));
				result = _tmp9_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label2) ? _tmp6_label2 : (_tmp6_label2 = g_quark_from_static_string ("network")))) {
		switch (0) {
			default:
			{
				gchar* _tmp10_;
				_tmp10_ = g_strdup (_ (FILES_PROTOCOL_NAME_NETWORK));
				result = _tmp10_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label3) ? _tmp6_label3 : (_tmp6_label3 = g_quark_from_static_string ("smb")))) {
		switch (0) {
			default:
			{
				gchar* _tmp11_;
				_tmp11_ = g_strdup (_ (FILES_PROTOCOL_NAME_SMB));
				result = _tmp11_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label4) ? _tmp6_label4 : (_tmp6_label4 = g_quark_from_static_string ("ftp")))) {
		switch (0) {
			default:
			{
				gchar* _tmp12_;
				_tmp12_ = g_strdup (_ (FILES_PROTOCOL_NAME_FTP));
				result = _tmp12_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label5) ? _tmp6_label5 : (_tmp6_label5 = g_quark_from_static_string ("sftp")))) {
		switch (0) {
			default:
			{
				gchar* _tmp13_;
				_tmp13_ = g_strdup (_ (FILES_PROTOCOL_NAME_SFTP));
				result = _tmp13_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label6) ? _tmp6_label6 : (_tmp6_label6 = g_quark_from_static_string ("afp")))) {
		switch (0) {
			default:
			{
				gchar* _tmp14_;
				_tmp14_ = g_strdup (_ (FILES_PROTOCOL_NAME_AFP));
				result = _tmp14_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label7) ? _tmp6_label7 : (_tmp6_label7 = g_quark_from_static_string ("afc")))) {
		switch (0) {
			default:
			{
				gchar* _tmp15_;
				_tmp15_ = g_strdup (_ (FILES_PROTOCOL_NAME_AFC));
				result = _tmp15_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label8) ? _tmp6_label8 : (_tmp6_label8 = g_quark_from_static_string ("dav")))) {
		switch (0) {
			default:
			{
				gchar* _tmp16_;
				_tmp16_ = g_strdup (_ (FILES_PROTOCOL_NAME_DAV));
				result = _tmp16_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label9) ? _tmp6_label9 : (_tmp6_label9 = g_quark_from_static_string ("davs")))) {
		switch (0) {
			default:
			{
				gchar* _tmp17_;
				_tmp17_ = g_strdup (_ (FILES_PROTOCOL_NAME_DAVS));
				result = _tmp17_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label10) ? _tmp6_label10 : (_tmp6_label10 = g_quark_from_static_string ("mtp")))) {
		switch (0) {
			default:
			{
				gchar* _tmp18_;
				_tmp18_ = g_strdup (_ (FILES_PROTOCOL_NAME_MTP));
				result = _tmp18_;
				_g_free0 (s);
				return result;
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label11) ? _tmp6_label11 : (_tmp6_label11 = g_quark_from_static_string ("gphoto2")))) {
		switch (0) {
			default:
			{
				gchar* _tmp19_;
				_tmp19_ = g_strdup (_ (FILES_PROTOCOL_NAME_GPHOTO2));
				result = _tmp19_;
				_g_free0 (s);
				return result;
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label12) ? _tmp6_label12 : (_tmp6_label12 = g_quark_from_static_string ("file")))) || (_tmp7_ == ((0 != _tmp6_label13) ? _tmp6_label13 : (_tmp6_label13 = g_quark_from_static_string (""))))) {
		switch (0) {
			default:
			{
				gchar* _tmp20_;
				_tmp20_ = g_strdup (_ (FILES_PROTOCOL_NAME_FILE));
				result = _tmp20_;
				_g_free0 (s);
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				gchar* _tmp21_;
				_tmp21_ = g_strdup (protocol);
				result = _tmp21_;
				_g_free0 (s);
				return result;
			}
		}
	}
}

