/* BasicLocationBar.c generated by valac 0.56.19, the Vala compiler
 * generated from BasicLocationBar.vala, do not modify */

#include "pantheon-files-core.h"
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib-object.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	FILES_VIEW_CHROME_BASIC_LOCATION_BAR_0_PROPERTY,
	FILES_VIEW_CHROME_BASIC_LOCATION_BAR_DISPLAYED_PATH_PROPERTY,
	FILES_VIEW_CHROME_BASIC_LOCATION_BAR_WITH_ANIMATION_PROPERTY,
	FILES_VIEW_CHROME_BASIC_LOCATION_BAR_HAS_FOCUS_PROPERTY,
	FILES_VIEW_CHROME_BASIC_LOCATION_BAR_NUM_PROPERTIES
};
static GParamSpec* files_view_chrome_basic_location_bar_properties[FILES_VIEW_CHROME_BASIC_LOCATION_BAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _FilesViewChromeBasicLocationBarPrivate {
	FilesViewChromeNavigatable* bread;
	gint minimum_width;
	gchar* _path;
};

static gint FilesViewChromeBasicLocationBar_private_offset;
static gpointer files_view_chrome_basic_location_bar_parent_class = NULL;
static FilesViewChromeLocatableIface * files_view_chrome_basic_location_bar_files_view_chrome_locatable_parent_iface = NULL;

static void files_view_chrome_basic_location_bar_real_get_preferred_width (GtkWidget* base,
                                                                    gint* minimum_width,
                                                                    gint* natural_width);
static void files_view_chrome_basic_location_bar_real_connect_signals (FilesViewChromeBasicLocationBar* self);
static void _files_view_chrome_basic_location_bar_after_bread_text_changed_files_view_chrome_navigatable_entry_text_changed (FilesViewChromeNavigatable* _sender,
                                                                                                                      const gchar* txt,
                                                                                                                      gpointer self);
static void _files_view_chrome_basic_location_bar_on_bread_activate_path_files_view_chrome_navigatable_activate_path (FilesViewChromeNavigatable* _sender,
                                                                                                               const gchar* path,
                                                                                                               FilesOpenFlag flag,
                                                                                                               gpointer self);
static void _files_view_chrome_basic_location_bar_on_bread_action_icon_press_files_view_chrome_navigatable_action_icon_press (FilesViewChromeNavigatable* _sender,
                                                                                                                       gpointer self);
static gboolean _files_view_chrome_basic_location_bar_after_bread_focus_in_event_gtk_widget_focus_in_event (GtkWidget* _sender,
                                                                                                     GdkEventFocus* event,
                                                                                                     gpointer self);
static gboolean _files_view_chrome_basic_location_bar_after_bread_focus_out_event_gtk_widget_focus_out_event (GtkWidget* _sender,
                                                                                                       GdkEventFocus* event,
                                                                                                       gpointer self);
static void files_view_chrome_basic_location_bar_real_after_bread_text_changed (FilesViewChromeBasicLocationBar* self,
                                                                         const gchar* txt);
static gboolean files_view_chrome_basic_location_bar_real_after_bread_focus_in_event (FilesViewChromeBasicLocationBar* self,
                                                                               GdkEventFocus* event);
static gboolean files_view_chrome_basic_location_bar_real_after_bread_focus_out_event (FilesViewChromeBasicLocationBar* self,
                                                                                GdkEventFocus* event);
static void files_view_chrome_basic_location_bar_real_on_bread_action_icon_press (FilesViewChromeBasicLocationBar* self);
static void files_view_chrome_basic_location_bar_real_on_bread_activate_path (FilesViewChromeBasicLocationBar* self,
                                                                       const gchar* path,
                                                                       FilesOpenFlag flag);
static void files_view_chrome_basic_location_bar_real_show_navigate_icon (FilesViewChromeBasicLocationBar* self);
static void files_view_chrome_basic_location_bar_real_hide_navigate_icon (FilesViewChromeBasicLocationBar* self);
static void files_view_chrome_basic_location_bar_real_set_display_path (FilesViewChromeBasicLocationBar* self,
                                                                 const gchar* path);
static gchar* files_view_chrome_basic_location_bar_real_get_display_path (FilesViewChromeLocatable* base);
static gboolean files_view_chrome_basic_location_bar_real_set_focussed (FilesViewChromeLocatable* base);
static GObject * files_view_chrome_basic_location_bar_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties);
static void files_view_chrome_basic_location_bar_finalize (GObject * obj);
static GType files_view_chrome_basic_location_bar_get_type_once (void);
static void _vala_files_view_chrome_basic_location_bar_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_files_view_chrome_basic_location_bar_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
files_view_chrome_basic_location_bar_get_instance_private (FilesViewChromeBasicLocationBar* self)
{
	return G_STRUCT_MEMBER_P (self, FilesViewChromeBasicLocationBar_private_offset);
}

static void
files_view_chrome_basic_location_bar_real_get_preferred_width (GtkWidget* base,
                                                               gint* minimum_width,
                                                               gint* natural_width)
{
	FilesViewChromeBasicLocationBar * self;
	gint _vala_minimum_width = 0;
	gint _vala_natural_width = 0;
	self = (FilesViewChromeBasicLocationBar*) base;
	_vala_minimum_width = self->priv->minimum_width;
	_vala_natural_width = 3000;
	if (minimum_width) {
		*minimum_width = _vala_minimum_width;
	}
	if (natural_width) {
		*natural_width = _vala_natural_width;
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

FilesViewChromeBasicLocationBar*
files_view_chrome_basic_location_bar_construct (GType object_type,
                                                FilesViewChromeNavigatable* _bread)
{
	FilesViewChromeBasicLocationBar * self = NULL;
	GtkWidget* _tmp2_;
	FilesViewChromeNavigatable* _tmp3_;
	self = (FilesViewChromeBasicLocationBar*) g_object_new (object_type, NULL);
	if (_bread == NULL) {
		FilesViewChromeBasicBreadcrumbsEntry* _tmp0_;
		_tmp0_ = files_view_chrome_basic_breadcrumbs_entry_new ();
		g_object_ref_sink (_tmp0_);
		_g_object_unref0 (self->priv->bread);
		self->priv->bread = (FilesViewChromeNavigatable*) _tmp0_;
	} else {
		FilesViewChromeNavigatable* _tmp1_;
		_tmp1_ = _g_object_ref0 (_bread);
		_g_object_unref0 (self->priv->bread);
		self->priv->bread = _tmp1_;
	}
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_bread, gtk_widget_get_type ()) ? ((GtkWidget*) _bread) : NULL);
	_g_object_unref0 (self->widget);
	self->widget = _tmp2_;
	_tmp3_ = self->priv->bread;
	gtk_box_pack_start ((GtkBox*) self, (GtkWidget*) _tmp3_, TRUE, TRUE, (guint) 0);
	files_view_chrome_basic_location_bar_connect_signals (self);
	gtk_widget_set_can_focus ((GtkWidget*) self, FALSE);
	return self;
}

FilesViewChromeBasicLocationBar*
files_view_chrome_basic_location_bar_new (FilesViewChromeNavigatable* _bread)
{
	return files_view_chrome_basic_location_bar_construct (FILES_VIEW_CHROME_TYPE_BASIC_LOCATION_BAR, _bread);
}

static void
_files_view_chrome_basic_location_bar_after_bread_text_changed_files_view_chrome_navigatable_entry_text_changed (FilesViewChromeNavigatable* _sender,
                                                                                                                 const gchar* txt,
                                                                                                                 gpointer self)
{
	files_view_chrome_basic_location_bar_after_bread_text_changed ((FilesViewChromeBasicLocationBar*) self, txt);
}

static void
_files_view_chrome_basic_location_bar_on_bread_activate_path_files_view_chrome_navigatable_activate_path (FilesViewChromeNavigatable* _sender,
                                                                                                          const gchar* path,
                                                                                                          FilesOpenFlag flag,
                                                                                                          gpointer self)
{
	files_view_chrome_basic_location_bar_on_bread_activate_path ((FilesViewChromeBasicLocationBar*) self, path, flag);
}

static void
_files_view_chrome_basic_location_bar_on_bread_action_icon_press_files_view_chrome_navigatable_action_icon_press (FilesViewChromeNavigatable* _sender,
                                                                                                                  gpointer self)
{
	files_view_chrome_basic_location_bar_on_bread_action_icon_press ((FilesViewChromeBasicLocationBar*) self);
}

static gboolean
_files_view_chrome_basic_location_bar_after_bread_focus_in_event_gtk_widget_focus_in_event (GtkWidget* _sender,
                                                                                            GdkEventFocus* event,
                                                                                            gpointer self)
{
	gboolean result;
	result = files_view_chrome_basic_location_bar_after_bread_focus_in_event ((FilesViewChromeBasicLocationBar*) self, event);
	return result;
}

static gboolean
_files_view_chrome_basic_location_bar_after_bread_focus_out_event_gtk_widget_focus_out_event (GtkWidget* _sender,
                                                                                              GdkEventFocus* event,
                                                                                              gpointer self)
{
	gboolean result;
	result = files_view_chrome_basic_location_bar_after_bread_focus_out_event ((FilesViewChromeBasicLocationBar*) self, event);
	return result;
}

static void
files_view_chrome_basic_location_bar_real_connect_signals (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeNavigatable* _tmp0_;
	FilesViewChromeNavigatable* _tmp1_;
	FilesViewChromeNavigatable* _tmp2_;
	FilesViewChromeNavigatable* _tmp3_;
	FilesViewChromeNavigatable* _tmp4_;
	_tmp0_ = self->priv->bread;
	g_signal_connect_object (_tmp0_, "entry-text-changed", (GCallback) _files_view_chrome_basic_location_bar_after_bread_text_changed_files_view_chrome_navigatable_entry_text_changed, self, G_CONNECT_AFTER);
	_tmp1_ = self->priv->bread;
	g_signal_connect_object (_tmp1_, "activate-path", (GCallback) _files_view_chrome_basic_location_bar_on_bread_activate_path_files_view_chrome_navigatable_activate_path, self, 0);
	_tmp2_ = self->priv->bread;
	g_signal_connect_object (_tmp2_, "action-icon-press", (GCallback) _files_view_chrome_basic_location_bar_on_bread_action_icon_press_files_view_chrome_navigatable_action_icon_press, self, 0);
	_tmp3_ = self->priv->bread;
	g_signal_connect_object ((GtkWidget*) _tmp3_, "focus-in-event", (GCallback) _files_view_chrome_basic_location_bar_after_bread_focus_in_event_gtk_widget_focus_in_event, self, G_CONNECT_AFTER);
	_tmp4_ = self->priv->bread;
	g_signal_connect_object ((GtkWidget*) _tmp4_, "focus-out-event", (GCallback) _files_view_chrome_basic_location_bar_after_bread_focus_out_event_gtk_widget_focus_out_event, self, G_CONNECT_AFTER);
}

void
files_view_chrome_basic_location_bar_connect_signals (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->connect_signals) {
		_klass_->connect_signals (self);
	}
}

static void
files_view_chrome_basic_location_bar_real_after_bread_text_changed (FilesViewChromeBasicLocationBar* self,
                                                                    const gchar* txt)
{
	g_return_if_fail (txt != NULL);
	if (g_strcmp0 (txt, "") == 0) {
		FilesViewChromeNavigatable* _tmp0_;
		FilesViewChromeNavigatable* _tmp1_;
		FilesViewChromeNavigatable* _tmp2_;
		_tmp0_ = self->priv->bread;
		files_view_chrome_navigatable_set_placeholder (_tmp0_, _ ("Type a path"));
		_tmp1_ = self->priv->bread;
		files_view_chrome_navigatable_set_action_icon_tooltip (_tmp1_, "");
		_tmp2_ = self->priv->bread;
		files_view_chrome_navigatable_hide_action_icon (_tmp2_);
	} else {
		FilesViewChromeNavigatable* _tmp3_;
		FilesViewChromeNavigatable* _tmp4_;
		_tmp3_ = self->priv->bread;
		files_view_chrome_navigatable_set_placeholder (_tmp3_, "");
		_tmp4_ = self->priv->bread;
		files_view_chrome_navigatable_set_default_action_icon_tooltip (_tmp4_);
	}
}

void
files_view_chrome_basic_location_bar_after_bread_text_changed (FilesViewChromeBasicLocationBar* self,
                                                               const gchar* txt)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->after_bread_text_changed) {
		_klass_->after_bread_text_changed (self, txt);
	}
}

static gboolean
files_view_chrome_basic_location_bar_real_after_bread_focus_in_event (FilesViewChromeBasicLocationBar* self,
                                                                      GdkEventFocus* event)
{
	gboolean result;
	g_return_val_if_fail (event != NULL, FALSE);
	files_view_chrome_basic_location_bar_show_navigate_icon (self);
	result = TRUE;
	return result;
}

gboolean
files_view_chrome_basic_location_bar_after_bread_focus_in_event (FilesViewChromeBasicLocationBar* self,
                                                                 GdkEventFocus* event)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_val_if_fail (self != NULL, FALSE);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->after_bread_focus_in_event) {
		return _klass_->after_bread_focus_in_event (self, event);
	}
	return FALSE;
}

static gboolean
files_view_chrome_basic_location_bar_real_after_bread_focus_out_event (FilesViewChromeBasicLocationBar* self,
                                                                       GdkEventFocus* event)
{
	gboolean result;
	g_return_val_if_fail (event != NULL, FALSE);
	files_view_chrome_basic_location_bar_hide_navigate_icon (self);
	result = TRUE;
	return result;
}

gboolean
files_view_chrome_basic_location_bar_after_bread_focus_out_event (FilesViewChromeBasicLocationBar* self,
                                                                  GdkEventFocus* event)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_val_if_fail (self != NULL, FALSE);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->after_bread_focus_out_event) {
		return _klass_->after_bread_focus_out_event (self, event);
	}
	return FALSE;
}

static void
files_view_chrome_basic_location_bar_real_on_bread_action_icon_press (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeNavigatable* _tmp0_;
	_tmp0_ = self->priv->bread;
	gtk_widget_activate ((GtkWidget*) _tmp0_);
}

void
files_view_chrome_basic_location_bar_on_bread_action_icon_press (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->on_bread_action_icon_press) {
		_klass_->on_bread_action_icon_press (self);
	}
}

static void
files_view_chrome_basic_location_bar_real_on_bread_activate_path (FilesViewChromeBasicLocationBar* self,
                                                                  const gchar* path,
                                                                  FilesOpenFlag flag)
{
	g_return_if_fail (path != NULL);
	g_signal_emit_by_name ((FilesViewChromeLocatable*) self, "path-change-request", path, flag);
}

void
files_view_chrome_basic_location_bar_on_bread_activate_path (FilesViewChromeBasicLocationBar* self,
                                                             const gchar* path,
                                                             FilesOpenFlag flag)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->on_bread_activate_path) {
		_klass_->on_bread_activate_path (self, path, flag);
	}
}

static void
files_view_chrome_basic_location_bar_real_show_navigate_icon (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeNavigatable* _tmp0_;
	_tmp0_ = self->priv->bread;
	files_view_chrome_navigatable_show_default_action_icon (_tmp0_);
}

void
files_view_chrome_basic_location_bar_show_navigate_icon (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->show_navigate_icon) {
		_klass_->show_navigate_icon (self);
	}
}

static void
files_view_chrome_basic_location_bar_real_hide_navigate_icon (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeNavigatable* _tmp0_;
	_tmp0_ = self->priv->bread;
	files_view_chrome_navigatable_hide_action_icon (_tmp0_);
}

void
files_view_chrome_basic_location_bar_hide_navigate_icon (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->hide_navigate_icon) {
		_klass_->hide_navigate_icon (self);
	}
}

void
files_view_chrome_basic_location_bar_show_breadcrumbs (FilesViewChromeBasicLocationBar* self)
{
	FilesViewChromeNavigatable* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	FilesViewChromeNavigatable* _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->bread;
	_tmp1_ = files_view_chrome_basic_location_bar_get_displayed_path (self);
	_tmp2_ = _tmp1_;
	files_view_chrome_navigatable_set_breadcrumbs_path (_tmp0_, _tmp2_);
	_tmp3_ = self->priv->bread;
	self->priv->minimum_width = files_view_chrome_navigatable_get_minimum_width (_tmp3_) + 48;
	gtk_widget_set_size_request ((GtkWidget*) self, self->priv->minimum_width, -1);
}

static void
files_view_chrome_basic_location_bar_real_set_display_path (FilesViewChromeBasicLocationBar* self,
                                                            const gchar* path)
{
	g_return_if_fail (path != NULL);
	files_view_chrome_basic_location_bar_set_displayed_path (self, path);
}

void
files_view_chrome_basic_location_bar_set_display_path (FilesViewChromeBasicLocationBar* self,
                                                       const gchar* path)
{
	FilesViewChromeBasicLocationBarClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = FILES_VIEW_CHROME_BASIC_LOCATION_BAR_GET_CLASS (self);
	if (_klass_->set_display_path) {
		_klass_->set_display_path (self, path);
	}
}

static gchar*
files_view_chrome_basic_location_bar_real_get_display_path (FilesViewChromeLocatable* base)
{
	FilesViewChromeBasicLocationBar * self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* result;
	self = (FilesViewChromeBasicLocationBar*) base;
	_tmp0_ = files_view_chrome_basic_location_bar_get_displayed_path (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	result = _tmp2_;
	return result;
}

static gboolean
files_view_chrome_basic_location_bar_real_set_focussed (FilesViewChromeLocatable* base)
{
	FilesViewChromeBasicLocationBar * self;
	FilesViewChromeNavigatable* _tmp0_;
	FilesViewChromeNavigatable* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean result;
	self = (FilesViewChromeBasicLocationBar*) base;
	_tmp0_ = self->priv->bread;
	gtk_widget_grab_focus ((GtkWidget*) _tmp0_);
	_tmp1_ = self->priv->bread;
	g_object_get ((GtkWidget*) _tmp1_, "has-focus", &_tmp2_, NULL);
	_tmp3_ = _tmp2_;
	result = _tmp3_;
	return result;
}

const gchar*
files_view_chrome_basic_location_bar_get_displayed_path (FilesViewChromeBasicLocationBar* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_path;
	result = _tmp0_;
	return result;
}

void
files_view_chrome_basic_location_bar_set_displayed_path (FilesViewChromeBasicLocationBar* self,
                                                         const gchar* value)
{
	g_return_if_fail (self != NULL);
	if (value == NULL) {
		g_critical ("BasicLocationBar.vala:31: Tried to set null path");
	} else {
		gboolean _tmp0_ = FALSE;
		const gchar* _tmp1_;
		_tmp1_ = self->priv->_path;
		if (_tmp1_ == NULL) {
			_tmp0_ = TRUE;
		} else {
			const gchar* _tmp2_;
			_tmp2_ = self->priv->_path;
			_tmp0_ = g_strcmp0 (_tmp2_, value) != 0;
		}
		if (_tmp0_) {
			gchar* _tmp3_;
			_tmp3_ = g_strdup (value);
			_g_free0 (self->priv->_path);
			self->priv->_path = _tmp3_;
			files_view_chrome_basic_location_bar_show_breadcrumbs (self);
		}
	}
	g_object_notify_by_pspec ((GObject *) self, files_view_chrome_basic_location_bar_properties[FILES_VIEW_CHROME_BASIC_LOCATION_BAR_DISPLAYED_PATH_PROPERTY]);
}

void
files_view_chrome_basic_location_bar_set_with_animation (FilesViewChromeBasicLocationBar* self,
                                                         gboolean value)
{
	FilesViewChromeNavigatable* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->bread;
	files_view_chrome_navigatable_set_animation_visible (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, files_view_chrome_basic_location_bar_properties[FILES_VIEW_CHROME_BASIC_LOCATION_BAR_WITH_ANIMATION_PROPERTY]);
}

gboolean
files_view_chrome_basic_location_bar_get_has_focus (FilesViewChromeBasicLocationBar* self)
{
	gboolean result;
	FilesViewChromeNavigatable* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->bread;
	g_object_get ((GtkWidget*) _tmp0_, "has-focus", &_tmp1_, NULL);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

static GObject *
files_view_chrome_basic_location_bar_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	FilesViewChromeBasicLocationBar * self;
	parent_class = G_OBJECT_CLASS (files_view_chrome_basic_location_bar_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FILES_VIEW_CHROME_TYPE_BASIC_LOCATION_BAR, FilesViewChromeBasicLocationBar);
	gtk_widget_set_margin_start ((GtkWidget*) self, 3);
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_CENTER);
	return obj;
}

static void
files_view_chrome_basic_location_bar_class_init (FilesViewChromeBasicLocationBarClass * klass,
                                                 gpointer klass_data)
{
	files_view_chrome_basic_location_bar_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &FilesViewChromeBasicLocationBar_private_offset);
	((GtkWidgetClass *) klass)->get_preferred_width = (void (*) (GtkWidget*, gint*, gint*)) files_view_chrome_basic_location_bar_real_get_preferred_width;
	((FilesViewChromeBasicLocationBarClass *) klass)->connect_signals = (void (*) (FilesViewChromeBasicLocationBar*)) files_view_chrome_basic_location_bar_real_connect_signals;
	((FilesViewChromeBasicLocationBarClass *) klass)->after_bread_text_changed = (void (*) (FilesViewChromeBasicLocationBar*, const gchar*)) files_view_chrome_basic_location_bar_real_after_bread_text_changed;
	((FilesViewChromeBasicLocationBarClass *) klass)->after_bread_focus_in_event = (gboolean (*) (FilesViewChromeBasicLocationBar*, GdkEventFocus*)) files_view_chrome_basic_location_bar_real_after_bread_focus_in_event;
	((FilesViewChromeBasicLocationBarClass *) klass)->after_bread_focus_out_event = (gboolean (*) (FilesViewChromeBasicLocationBar*, GdkEventFocus*)) files_view_chrome_basic_location_bar_real_after_bread_focus_out_event;
	((FilesViewChromeBasicLocationBarClass *) klass)->on_bread_action_icon_press = (void (*) (FilesViewChromeBasicLocationBar*)) files_view_chrome_basic_location_bar_real_on_bread_action_icon_press;
	((FilesViewChromeBasicLocationBarClass *) klass)->on_bread_activate_path = (void (*) (FilesViewChromeBasicLocationBar*, const gchar*, FilesOpenFlag)) files_view_chrome_basic_location_bar_real_on_bread_activate_path;
	((FilesViewChromeBasicLocationBarClass *) klass)->show_navigate_icon = (void (*) (FilesViewChromeBasicLocationBar*)) files_view_chrome_basic_location_bar_real_show_navigate_icon;
	((FilesViewChromeBasicLocationBarClass *) klass)->hide_navigate_icon = (void (*) (FilesViewChromeBasicLocationBar*)) files_view_chrome_basic_location_bar_real_hide_navigate_icon;
	((FilesViewChromeBasicLocationBarClass *) klass)->set_display_path = (void (*) (FilesViewChromeBasicLocationBar*, const gchar*)) files_view_chrome_basic_location_bar_real_set_display_path;
	G_OBJECT_CLASS (klass)->get_property = _vala_files_view_chrome_basic_location_bar_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_files_view_chrome_basic_location_bar_set_property;
	G_OBJECT_CLASS (klass)->constructor = files_view_chrome_basic_location_bar_constructor;
	G_OBJECT_CLASS (klass)->finalize = files_view_chrome_basic_location_bar_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), FILES_VIEW_CHROME_BASIC_LOCATION_BAR_DISPLAYED_PATH_PROPERTY, files_view_chrome_basic_location_bar_properties[FILES_VIEW_CHROME_BASIC_LOCATION_BAR_DISPLAYED_PATH_PROPERTY] = g_param_spec_string ("displayed-path", "displayed-path", "displayed-path", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FILES_VIEW_CHROME_BASIC_LOCATION_BAR_WITH_ANIMATION_PROPERTY, files_view_chrome_basic_location_bar_properties[FILES_VIEW_CHROME_BASIC_LOCATION_BAR_WITH_ANIMATION_PROPERTY] = g_param_spec_boolean ("with-animation", "with-animation", "with-animation", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FILES_VIEW_CHROME_BASIC_LOCATION_BAR_HAS_FOCUS_PROPERTY, files_view_chrome_basic_location_bar_properties[FILES_VIEW_CHROME_BASIC_LOCATION_BAR_HAS_FOCUS_PROPERTY] = g_param_spec_boolean ("has-focus", "has-focus", "has-focus", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
files_view_chrome_basic_location_bar_files_view_chrome_locatable_interface_init (FilesViewChromeLocatableIface * iface,
                                                                                 gpointer iface_data)
{
	files_view_chrome_basic_location_bar_files_view_chrome_locatable_parent_iface = g_type_interface_peek_parent (iface);
	iface->set_display_path = (void (*) (FilesViewChromeLocatable*, const gchar*)) files_view_chrome_basic_location_bar_set_display_path;
	iface->get_display_path = (gchar* (*) (FilesViewChromeLocatable*)) files_view_chrome_basic_location_bar_real_get_display_path;
	iface->set_focussed = (gboolean (*) (FilesViewChromeLocatable*)) files_view_chrome_basic_location_bar_real_set_focussed;
}

static void
files_view_chrome_basic_location_bar_instance_init (FilesViewChromeBasicLocationBar * self,
                                                    gpointer klass)
{
	self->priv = files_view_chrome_basic_location_bar_get_instance_private (self);
	self->priv->minimum_width = 100;
}

static void
files_view_chrome_basic_location_bar_finalize (GObject * obj)
{
	FilesViewChromeBasicLocationBar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FILES_VIEW_CHROME_TYPE_BASIC_LOCATION_BAR, FilesViewChromeBasicLocationBar);
	_g_object_unref0 (self->priv->bread);
	_g_object_unref0 (self->widget);
	_g_free0 (self->priv->_path);
	G_OBJECT_CLASS (files_view_chrome_basic_location_bar_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
files_view_chrome_basic_location_bar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (FilesViewChromeBasicLocationBarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) files_view_chrome_basic_location_bar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FilesViewChromeBasicLocationBar), 0, (GInstanceInitFunc) files_view_chrome_basic_location_bar_instance_init, NULL };
	static const GInterfaceInfo files_view_chrome_locatable_info = { (GInterfaceInitFunc) files_view_chrome_basic_location_bar_files_view_chrome_locatable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType files_view_chrome_basic_location_bar_type_id;
	files_view_chrome_basic_location_bar_type_id = g_type_register_static (gtk_box_get_type (), "FilesViewChromeBasicLocationBar", &g_define_type_info, 0);
	g_type_add_interface_static (files_view_chrome_basic_location_bar_type_id, FILES_VIEW_CHROME_TYPE_LOCATABLE, &files_view_chrome_locatable_info);
	FilesViewChromeBasicLocationBar_private_offset = g_type_add_instance_private (files_view_chrome_basic_location_bar_type_id, sizeof (FilesViewChromeBasicLocationBarPrivate));
	return files_view_chrome_basic_location_bar_type_id;
}

GType
files_view_chrome_basic_location_bar_get_type (void)
{
	static volatile gsize files_view_chrome_basic_location_bar_type_id__once = 0;
	if (g_once_init_enter (&files_view_chrome_basic_location_bar_type_id__once)) {
		GType files_view_chrome_basic_location_bar_type_id;
		files_view_chrome_basic_location_bar_type_id = files_view_chrome_basic_location_bar_get_type_once ();
		g_once_init_leave (&files_view_chrome_basic_location_bar_type_id__once, files_view_chrome_basic_location_bar_type_id);
	}
	return files_view_chrome_basic_location_bar_type_id__once;
}

static void
_vala_files_view_chrome_basic_location_bar_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	FilesViewChromeBasicLocationBar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FILES_VIEW_CHROME_TYPE_BASIC_LOCATION_BAR, FilesViewChromeBasicLocationBar);
	switch (property_id) {
		case FILES_VIEW_CHROME_BASIC_LOCATION_BAR_DISPLAYED_PATH_PROPERTY:
		g_value_set_string (value, files_view_chrome_basic_location_bar_get_displayed_path (self));
		break;
		case FILES_VIEW_CHROME_BASIC_LOCATION_BAR_HAS_FOCUS_PROPERTY:
		g_value_set_boolean (value, files_view_chrome_basic_location_bar_get_has_focus (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_files_view_chrome_basic_location_bar_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	FilesViewChromeBasicLocationBar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FILES_VIEW_CHROME_TYPE_BASIC_LOCATION_BAR, FilesViewChromeBasicLocationBar);
	switch (property_id) {
		case FILES_VIEW_CHROME_BASIC_LOCATION_BAR_DISPLAYED_PATH_PROPERTY:
		files_view_chrome_basic_location_bar_set_displayed_path (self, g_value_get_string (value));
		break;
		case FILES_VIEW_CHROME_BASIC_LOCATION_BAR_WITH_ANIMATION_PROPERTY:
		files_view_chrome_basic_location_bar_set_with_animation (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

