/* Enums.c generated by valac 0.56.19, the Vala compiler
 * generated from Enums.vala, do not modify */

#include "pantheon-files-core.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

gchar*
files_window_state_to_string (FilesWindowState self)
{
	gchar* result;
	switch (self) {
		case FILES_WINDOW_STATE_NORMAL:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup ("Marlin.WindowState.NORMAL");
			result = _tmp0_;
			return result;
		}
		case FILES_WINDOW_STATE_MAXIMIZED:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup ("Marlin.WindowState.MAXIMIZED");
			result = _tmp1_;
			return result;
		}
		default:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup ("Marlin.WindowState.INVALID");
			result = _tmp2_;
			return result;
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_window_state_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_WINDOW_STATE_NORMAL, "FILES_WINDOW_STATE_NORMAL", "normal"}, {FILES_WINDOW_STATE_MAXIMIZED, "FILES_WINDOW_STATE_MAXIMIZED", "maximized"}, {FILES_WINDOW_STATE_INVALID, "FILES_WINDOW_STATE_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_window_state_type_id;
	files_window_state_type_id = g_enum_register_static ("FilesWindowState", values);
	return files_window_state_type_id;
}

GType
files_window_state_get_type (void)
{
	static volatile gsize files_window_state_type_id__once = 0;
	if (g_once_init_enter (&files_window_state_type_id__once)) {
		GType files_window_state_type_id;
		files_window_state_type_id = files_window_state_get_type_once ();
		g_once_init_leave (&files_window_state_type_id__once, files_window_state_type_id);
	}
	return files_window_state_type_id__once;
}

 G_GNUC_NO_INLINE static GType
files_view_mode_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_VIEW_MODE_ICON, "FILES_VIEW_MODE_ICON", "icon"}, {FILES_VIEW_MODE_LIST, "FILES_VIEW_MODE_LIST", "list"}, {FILES_VIEW_MODE_MILLER_COLUMNS, "FILES_VIEW_MODE_MILLER_COLUMNS", "miller-columns"}, {FILES_VIEW_MODE_CURRENT, "FILES_VIEW_MODE_CURRENT", "current"}, {FILES_VIEW_MODE_PREFERRED, "FILES_VIEW_MODE_PREFERRED", "preferred"}, {FILES_VIEW_MODE_INVALID, "FILES_VIEW_MODE_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_view_mode_type_id;
	files_view_mode_type_id = g_enum_register_static ("FilesViewMode", values);
	return files_view_mode_type_id;
}

GType
files_view_mode_get_type (void)
{
	static volatile gsize files_view_mode_type_id__once = 0;
	if (g_once_init_enter (&files_view_mode_type_id__once)) {
		GType files_view_mode_type_id;
		files_view_mode_type_id = files_view_mode_get_type_once ();
		g_once_init_leave (&files_view_mode_type_id__once, files_view_mode_type_id);
	}
	return files_view_mode_type_id__once;
}

 G_GNUC_NO_INLINE static GType
files_open_flag_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_OPEN_FLAG_DEFAULT, "FILES_OPEN_FLAG_DEFAULT", "default"}, {FILES_OPEN_FLAG_NEW_ROOT, "FILES_OPEN_FLAG_NEW_ROOT", "new-root"}, {FILES_OPEN_FLAG_NEW_TAB, "FILES_OPEN_FLAG_NEW_TAB", "new-tab"}, {FILES_OPEN_FLAG_NEW_WINDOW, "FILES_OPEN_FLAG_NEW_WINDOW", "new-window"}, {FILES_OPEN_FLAG_APP, "FILES_OPEN_FLAG_APP", "app"}, {0, NULL, NULL}};
	GType files_open_flag_type_id;
	files_open_flag_type_id = g_enum_register_static ("FilesOpenFlag", values);
	return files_open_flag_type_id;
}

GType
files_open_flag_get_type (void)
{
	static volatile gsize files_open_flag_type_id__once = 0;
	if (g_once_init_enter (&files_open_flag_type_id__once)) {
		GType files_open_flag_type_id;
		files_open_flag_type_id = files_open_flag_get_type_once ();
		g_once_init_leave (&files_open_flag_type_id__once, files_open_flag_type_id);
	}
	return files_open_flag_type_id__once;
}

FilesIconSize
files_zoom_level_to_icon_size (FilesZoomLevel self)
{
	FilesIconSize result;
	switch (self) {
		case FILES_ZOOM_LEVEL_SMALLEST:
		{
			result = FILES_ICON_SIZE_SMALLEST;
			return result;
		}
		case FILES_ZOOM_LEVEL_SMALLER:
		{
			result = FILES_ICON_SIZE_SMALLER;
			return result;
		}
		case FILES_ZOOM_LEVEL_SMALL:
		{
			result = FILES_ICON_SIZE_SMALL;
			return result;
		}
		case FILES_ZOOM_LEVEL_NORMAL:
		{
			result = FILES_ICON_SIZE_NORMAL;
			return result;
		}
		case FILES_ZOOM_LEVEL_LARGE:
		{
			result = FILES_ICON_SIZE_LARGE;
			return result;
		}
		case FILES_ZOOM_LEVEL_LARGER:
		{
			result = FILES_ICON_SIZE_LARGER;
			return result;
		}
		case FILES_ZOOM_LEVEL_HUGE:
		{
			result = FILES_ICON_SIZE_HUGE;
			return result;
		}
		case FILES_ZOOM_LEVEL_HUGER:
		{
			result = FILES_ICON_SIZE_HUGER;
			return result;
		}
		default:
		{
			result = FILES_ICON_SIZE_LARGEST;
			return result;
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_zoom_level_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_ZOOM_LEVEL_SMALLEST, "FILES_ZOOM_LEVEL_SMALLEST", "smallest"}, {FILES_ZOOM_LEVEL_SMALLER, "FILES_ZOOM_LEVEL_SMALLER", "smaller"}, {FILES_ZOOM_LEVEL_SMALL, "FILES_ZOOM_LEVEL_SMALL", "small"}, {FILES_ZOOM_LEVEL_NORMAL, "FILES_ZOOM_LEVEL_NORMAL", "normal"}, {FILES_ZOOM_LEVEL_LARGE, "FILES_ZOOM_LEVEL_LARGE", "large"}, {FILES_ZOOM_LEVEL_LARGER, "FILES_ZOOM_LEVEL_LARGER", "larger"}, {FILES_ZOOM_LEVEL_HUGE, "FILES_ZOOM_LEVEL_HUGE", "huge"}, {FILES_ZOOM_LEVEL_HUGER, "FILES_ZOOM_LEVEL_HUGER", "huger"}, {FILES_ZOOM_LEVEL_LARGEST, "FILES_ZOOM_LEVEL_LARGEST", "largest"}, {FILES_ZOOM_LEVEL_N_LEVELS, "FILES_ZOOM_LEVEL_N_LEVELS", "n-levels"}, {FILES_ZOOM_LEVEL_INVALID, "FILES_ZOOM_LEVEL_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_zoom_level_type_id;
	files_zoom_level_type_id = g_enum_register_static ("FilesZoomLevel", values);
	return files_zoom_level_type_id;
}

GType
files_zoom_level_get_type (void)
{
	static volatile gsize files_zoom_level_type_id__once = 0;
	if (g_once_init_enter (&files_zoom_level_type_id__once)) {
		GType files_zoom_level_type_id;
		files_zoom_level_type_id = files_zoom_level_get_type_once ();
		g_once_init_leave (&files_zoom_level_type_id__once, files_zoom_level_type_id);
	}
	return files_zoom_level_type_id__once;
}

 G_GNUC_NO_INLINE static GType
files_icon_size_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_ICON_SIZE_EMBLEM, "FILES_ICON_SIZE_EMBLEM", "emblem"}, {FILES_ICON_SIZE_SMALLEST, "FILES_ICON_SIZE_SMALLEST", "smallest"}, {FILES_ICON_SIZE_LARGE_EMBLEM, "FILES_ICON_SIZE_LARGE_EMBLEM", "large-emblem"}, {FILES_ICON_SIZE_SMALLER, "FILES_ICON_SIZE_SMALLER", "smaller"}, {FILES_ICON_SIZE_SMALL, "FILES_ICON_SIZE_SMALL", "small"}, {FILES_ICON_SIZE_NORMAL, "FILES_ICON_SIZE_NORMAL", "normal"}, {FILES_ICON_SIZE_LARGE, "FILES_ICON_SIZE_LARGE", "large"}, {FILES_ICON_SIZE_LARGER, "FILES_ICON_SIZE_LARGER", "larger"}, {FILES_ICON_SIZE_HUGE, "FILES_ICON_SIZE_HUGE", "huge"}, {FILES_ICON_SIZE_HUGER, "FILES_ICON_SIZE_HUGER", "huger"}, {FILES_ICON_SIZE_LARGEST, "FILES_ICON_SIZE_LARGEST", "largest"}, {0, NULL, NULL}};
	GType files_icon_size_type_id;
	files_icon_size_type_id = g_enum_register_static ("FilesIconSize", values);
	return files_icon_size_type_id;
}

GType
files_icon_size_get_type (void)
{
	static volatile gsize files_icon_size_type_id__once = 0;
	if (g_once_init_enter (&files_icon_size_type_id__once)) {
		GType files_icon_size_type_id;
		files_icon_size_type_id = files_icon_size_get_type_once ();
		g_once_init_leave (&files_icon_size_type_id__once, files_icon_size_type_id);
	}
	return files_icon_size_type_id__once;
}

 G_GNUC_NO_INLINE static GType
files_target_type_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_TARGET_TYPE_STRING, "FILES_TARGET_TYPE_STRING", "string"}, {FILES_TARGET_TYPE_TEXT_URI_LIST, "FILES_TARGET_TYPE_TEXT_URI_LIST", "text-uri-list"}, {FILES_TARGET_TYPE_XDND_DIRECT_SAVE0, "FILES_TARGET_TYPE_XDND_DIRECT_SAVE0", "xdnd-direct-save0"}, {FILES_TARGET_TYPE_NETSCAPE_URL, "FILES_TARGET_TYPE_NETSCAPE_URL", "netscape-url"}, {FILES_TARGET_TYPE_BOOKMARK_ROW, "FILES_TARGET_TYPE_BOOKMARK_ROW", "bookmark-row"}, {0, NULL, NULL}};
	GType files_target_type_type_id;
	files_target_type_type_id = g_enum_register_static ("FilesTargetType", values);
	return files_target_type_type_id;
}

GType
files_target_type_get_type (void)
{
	static volatile gsize files_target_type_type_id__once = 0;
	if (g_once_init_enter (&files_target_type_type_id__once)) {
		GType files_target_type_type_id;
		files_target_type_type_id = files_target_type_get_type_once ();
		g_once_init_leave (&files_target_type_type_id__once, files_target_type_type_id);
	}
	return files_target_type_type_id__once;
}

gchar*
files_sort_by_to_string (FilesSortBy self)
{
	gchar* result;
	switch (self) {
		case FILES_SORT_BY_NAME:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Name"));
			result = _tmp0_;
			return result;
		}
		case FILES_SORT_BY_CREATED:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Creation Date"));
			result = _tmp1_;
			return result;
		}
		case FILES_SORT_BY_MODIFIED:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Last modification date"));
			result = _tmp2_;
			return result;
		}
		case FILES_SORT_BY_SIZE:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("Size"));
			result = _tmp3_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_sort_by_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_SORT_BY_NAME, "FILES_SORT_BY_NAME", "name"}, {FILES_SORT_BY_CREATED, "FILES_SORT_BY_CREATED", "created"}, {FILES_SORT_BY_MODIFIED, "FILES_SORT_BY_MODIFIED", "modified"}, {FILES_SORT_BY_SIZE, "FILES_SORT_BY_SIZE", "size"}, {0, NULL, NULL}};
	GType files_sort_by_type_id;
	files_sort_by_type_id = g_enum_register_static ("FilesSortBy", values);
	return files_sort_by_type_id;
}

GType
files_sort_by_get_type (void)
{
	static volatile gsize files_sort_by_type_id__once = 0;
	if (g_once_init_enter (&files_sort_by_type_id__once)) {
		GType files_sort_by_type_id;
		files_sort_by_type_id = files_sort_by_get_type_once ();
		g_once_init_leave (&files_sort_by_type_id__once, files_sort_by_type_id);
	}
	return files_sort_by_type_id__once;
}

 G_GNUC_NO_INLINE static GType
files_rename_status_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_RENAME_STATUS_VALID, "FILES_RENAME_STATUS_VALID", "valid"}, {FILES_RENAME_STATUS_IGNORED, "FILES_RENAME_STATUS_IGNORED", "ignored"}, {FILES_RENAME_STATUS_INVALID, "FILES_RENAME_STATUS_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_rename_status_type_id;
	files_rename_status_type_id = g_enum_register_static ("FilesRenameStatus", values);
	return files_rename_status_type_id;
}

GType
files_rename_status_get_type (void)
{
	static volatile gsize files_rename_status_type_id__once = 0;
	if (g_once_init_enter (&files_rename_status_type_id__once)) {
		GType files_rename_status_type_id;
		files_rename_status_type_id = files_rename_status_get_type_once ();
		g_once_init_leave (&files_rename_status_type_id__once, files_rename_status_type_id);
	}
	return files_rename_status_type_id__once;
}

gchar*
files_rename_mode_to_string (FilesRenameMode self)
{
	gchar* result;
	switch (self) {
		case FILES_RENAME_MODE_NUMBER_SEQUENCE:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Number sequence"));
			result = _tmp0_;
			return result;
		}
		case FILES_RENAME_MODE_TEXT:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Text"));
			result = _tmp1_;
			return result;
		}
		case FILES_RENAME_MODE_DATETIME:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Date"));
			result = _tmp2_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_rename_mode_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_RENAME_MODE_TEXT, "FILES_RENAME_MODE_TEXT", "text"}, {FILES_RENAME_MODE_NUMBER_SEQUENCE, "FILES_RENAME_MODE_NUMBER_SEQUENCE", "number-sequence"}, {FILES_RENAME_MODE_DATETIME, "FILES_RENAME_MODE_DATETIME", "datetime"}, {FILES_RENAME_MODE_INVALID, "FILES_RENAME_MODE_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_rename_mode_type_id;
	files_rename_mode_type_id = g_enum_register_static ("FilesRenameMode", values);
	return files_rename_mode_type_id;
}

GType
files_rename_mode_get_type (void)
{
	static volatile gsize files_rename_mode_type_id__once = 0;
	if (g_once_init_enter (&files_rename_mode_type_id__once)) {
		GType files_rename_mode_type_id;
		files_rename_mode_type_id = files_rename_mode_get_type_once ();
		g_once_init_leave (&files_rename_mode_type_id__once, files_rename_mode_type_id);
	}
	return files_rename_mode_type_id__once;
}

gchar*
files_rename_position_to_string (FilesRenamePosition self)
{
	gchar* result;
	switch (self) {
		case FILES_RENAME_POSITION_SUFFIX:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Suffix"));
			result = _tmp0_;
			return result;
		}
		case FILES_RENAME_POSITION_PREFIX:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Prefix"));
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

gchar*
files_rename_position_to_placeholder (FilesRenamePosition self)
{
	gchar* result;
	switch (self) {
		case FILES_RENAME_POSITION_SUFFIX:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Text to put at the end"));
			result = _tmp0_;
			return result;
		}
		case FILES_RENAME_POSITION_PREFIX:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Text to put at the start"));
			result = _tmp1_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_rename_position_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_RENAME_POSITION_SUFFIX, "FILES_RENAME_POSITION_SUFFIX", "suffix"}, {FILES_RENAME_POSITION_PREFIX, "FILES_RENAME_POSITION_PREFIX", "prefix"}, {FILES_RENAME_POSITION_INVALID, "FILES_RENAME_POSITION_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_rename_position_type_id;
	files_rename_position_type_id = g_enum_register_static ("FilesRenamePosition", values);
	return files_rename_position_type_id;
}

GType
files_rename_position_get_type (void)
{
	static volatile gsize files_rename_position_type_id__once = 0;
	if (g_once_init_enter (&files_rename_position_type_id__once)) {
		GType files_rename_position_type_id;
		files_rename_position_type_id = files_rename_position_get_type_once ();
		g_once_init_leave (&files_rename_position_type_id__once, files_rename_position_type_id);
	}
	return files_rename_position_type_id__once;
}

gchar*
files_rename_date_format_to_string (FilesRenameDateFormat self)
{
	gchar* result;
	switch (self) {
		case FILES_RENAME_DATE_FORMAT_DEFAULT:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Default Format - Date only"));
			result = _tmp0_;
			return result;
		}
		case FILES_RENAME_DATE_FORMAT_DEFAULT_DATETIME:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Default Format - Date and Time"));
			result = _tmp1_;
			return result;
		}
		case FILES_RENAME_DATE_FORMAT_LOCALE:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Locale Format - Date and Time"));
			result = _tmp2_;
			return result;
		}
		case FILES_RENAME_DATE_FORMAT_ISO_DATE:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("ISO 8601 Format - Date only"));
			result = _tmp3_;
			return result;
		}
		case FILES_RENAME_DATE_FORMAT_ISO_DATETIME:
		{
			gchar* _tmp4_;
			_tmp4_ = g_strdup (_ ("ISO 8601 Format - Date and Time"));
			result = _tmp4_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_rename_date_format_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_RENAME_DATE_FORMAT_DEFAULT, "FILES_RENAME_DATE_FORMAT_DEFAULT", "default"}, {FILES_RENAME_DATE_FORMAT_DEFAULT_DATETIME, "FILES_RENAME_DATE_FORMAT_DEFAULT_DATETIME", "default-datetime"}, {FILES_RENAME_DATE_FORMAT_LOCALE, "FILES_RENAME_DATE_FORMAT_LOCALE", "locale"}, {FILES_RENAME_DATE_FORMAT_ISO_DATE, "FILES_RENAME_DATE_FORMAT_ISO_DATE", "iso-date"}, {FILES_RENAME_DATE_FORMAT_ISO_DATETIME, "FILES_RENAME_DATE_FORMAT_ISO_DATETIME", "iso-datetime"}, {FILES_RENAME_DATE_FORMAT_INVALID, "FILES_RENAME_DATE_FORMAT_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_rename_date_format_type_id;
	files_rename_date_format_type_id = g_enum_register_static ("FilesRenameDateFormat", values);
	return files_rename_date_format_type_id;
}

GType
files_rename_date_format_get_type (void)
{
	static volatile gsize files_rename_date_format_type_id__once = 0;
	if (g_once_init_enter (&files_rename_date_format_type_id__once)) {
		GType files_rename_date_format_type_id;
		files_rename_date_format_type_id = files_rename_date_format_get_type_once ();
		g_once_init_leave (&files_rename_date_format_type_id__once, files_rename_date_format_type_id);
	}
	return files_rename_date_format_type_id__once;
}

gchar*
files_rename_date_source_to_string (FilesRenameDateSource self)
{
	gchar* result;
	switch (self) {
		case FILES_RENAME_DATE_SOURCE_CREATED:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Date created"));
			result = _tmp0_;
			return result;
		}
		case FILES_RENAME_DATE_SOURCE_MODIFIED:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Date Modified"));
			result = _tmp1_;
			return result;
		}
		case FILES_RENAME_DATE_SOURCE_NOW:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Current Date"));
			result = _tmp2_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_rename_date_source_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_RENAME_DATE_SOURCE_CREATED, "FILES_RENAME_DATE_SOURCE_CREATED", "created"}, {FILES_RENAME_DATE_SOURCE_MODIFIED, "FILES_RENAME_DATE_SOURCE_MODIFIED", "modified"}, {FILES_RENAME_DATE_SOURCE_NOW, "FILES_RENAME_DATE_SOURCE_NOW", "now"}, {FILES_RENAME_DATE_SOURCE_INVALID, "FILES_RENAME_DATE_SOURCE_INVALID", "invalid"}, {0, NULL, NULL}};
	GType files_rename_date_source_type_id;
	files_rename_date_source_type_id = g_enum_register_static ("FilesRenameDateSource", values);
	return files_rename_date_source_type_id;
}

GType
files_rename_date_source_get_type (void)
{
	static volatile gsize files_rename_date_source_type_id__once = 0;
	if (g_once_init_enter (&files_rename_date_source_type_id__once)) {
		GType files_rename_date_source_type_id;
		files_rename_date_source_type_id = files_rename_date_source_get_type_once ();
		g_once_init_leave (&files_rename_date_source_type_id__once, files_rename_date_source_type_id);
	}
	return files_rename_date_source_type_id__once;
}

gchar*
files_date_format_mode_to_string (FilesDateFormatMode self)
{
	gchar* result;
	switch (self) {
		case FILES_DATE_FORMAT_MODE_ISO:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("ISO"));
			result = _tmp0_;
			return result;
		}
		case FILES_DATE_FORMAT_MODE_LOCALE:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Locale"));
			result = _tmp1_;
			return result;
		}
		case FILES_DATE_FORMAT_MODE_INFORMAL:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Informal"));
			result = _tmp2_;
			return result;
		}
		case FILES_DATE_FORMAT_MODE_COMPACT:
		{
			gchar* _tmp3_;
			_tmp3_ = g_strdup (_ ("Compact"));
			result = _tmp3_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
files_date_format_mode_get_type_once (void)
{
	static const GEnumValue values[] = {{FILES_DATE_FORMAT_MODE_ISO, "FILES_DATE_FORMAT_MODE_ISO", "iso"}, {FILES_DATE_FORMAT_MODE_LOCALE, "FILES_DATE_FORMAT_MODE_LOCALE", "locale"}, {FILES_DATE_FORMAT_MODE_INFORMAL, "FILES_DATE_FORMAT_MODE_INFORMAL", "informal"}, {FILES_DATE_FORMAT_MODE_COMPACT, "FILES_DATE_FORMAT_MODE_COMPACT", "compact"}, {0, NULL, NULL}};
	GType files_date_format_mode_type_id;
	files_date_format_mode_type_id = g_enum_register_static ("FilesDateFormatMode", values);
	return files_date_format_mode_type_id;
}

GType
files_date_format_mode_get_type (void)
{
	static volatile gsize files_date_format_mode_type_id__once = 0;
	if (g_once_init_enter (&files_date_format_mode_type_id__once)) {
		GType files_date_format_mode_type_id;
		files_date_format_mode_type_id = files_date_format_mode_get_type_once ();
		g_once_init_leave (&files_date_format_mode_type_id__once, files_date_format_mode_type_id);
	}
	return files_date_format_mode_type_id__once;
}

