/* pantheon-files-trash.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_PANTHEON_FILES_TRASH_PANTHEON_FILES_TRASH_H__
#define __PLUGINS_PANTHEON_FILES_TRASH_PANTHEON_FILES_TRASH_H__

#include "pantheon-files-core.h"
#include <glib-object.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define FILES_PLUGINS_TYPE_TRASH (files_plugins_trash_get_type ())
#define FILES_PLUGINS_TRASH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FILES_PLUGINS_TYPE_TRASH, FilesPluginsTrash))
#define FILES_PLUGINS_TRASH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FILES_PLUGINS_TYPE_TRASH, FilesPluginsTrashClass))
#define FILES_PLUGINS_IS_TRASH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FILES_PLUGINS_TYPE_TRASH))
#define FILES_PLUGINS_IS_TRASH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FILES_PLUGINS_TYPE_TRASH))
#define FILES_PLUGINS_TRASH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FILES_PLUGINS_TYPE_TRASH, FilesPluginsTrashClass))

typedef struct _FilesPluginsTrash FilesPluginsTrash;
typedef struct _FilesPluginsTrashClass FilesPluginsTrashClass;
typedef struct _FilesPluginsTrashPrivate FilesPluginsTrashPrivate;

struct _FilesPluginsTrash {
	FilesPluginsBase parent_instance;
	FilesPluginsTrashPrivate * priv;
};

struct _FilesPluginsTrashClass {
	FilesPluginsBaseClass parent_class;
};

VALA_EXTERN GType files_plugins_trash_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FilesPluginsTrash, files_plugins_base_unref)
VALA_EXTERN FilesPluginsTrash* files_plugins_trash_new (void);
VALA_EXTERN FilesPluginsTrash* files_plugins_trash_construct (GType object_type);
VALA_EXTERN FilesPluginsBase* module_init (void);

G_END_DECLS

#endif
